from .... pyaz_utils import call_az
from . import throughput


def create(account_name, database_name, name, partition_key_path, resource_group, conflict_resolution_policy=None, idx=None, max_throughput=None, throughput=None, ttl=None):
    '''
    Create an Gremlin graph under an Azure Cosmos DB Gremlin database.
    '''
    return call_az("az cosmosdb gremlin graph create", locals())


def update(account_name, database_name, name, resource_group, idx=None, ttl=None):
    '''
    Update an Gremlin graph under an Azure Cosmos DB Gremlin database.
    '''
    return call_az("az cosmosdb gremlin graph update", locals())


def exists(account_name, database_name, name, resource_group):
    return call_az("az cosmosdb gremlin graph exists", locals())


def list(account_name, database_name, resource_group):
    '''
    List the Gremlin graphs under an Azure Cosmos DB Gremlin database.
    '''
    return call_az("az cosmosdb gremlin graph list", locals())


def show(account_name, database_name, name, resource_group):
    '''
    Show the details of a Gremlin graph under an Azure Cosmos DB Gremlin database.
    '''
    return call_az("az cosmosdb gremlin graph show", locals())


def delete(account_name, database_name, name, resource_group, yes=None):
    '''
    Delete the Gremlin graph under an Azure Cosmos DB Gremlin database.
    '''
    return call_az("az cosmosdb gremlin graph delete", locals())




from ... pyaz_utils import call_az

def create(name, resource_group, workspace, caching_type=None, config_file=None, disk_count=None, disk_size=None, generate_ssh_keys=None, no_wait=None, password=None, ssh_key=None, storage_sku=None, subnet=None, user_name=None, vm_size=None):
    '''
    Create a file server.
    '''
    return call_az("az batchai file-server create", locals())


def list(resource_group, workspace):
    '''
    List file servers.
    '''
    return call_az("az batchai file-server list", locals())




from .... pyaz_utils import call_az

def assign(gateway_name, identity, resource_group, no_wait=None):
    '''
    Assign a managed service identity to an application-gateway
    '''
    return call_az("az network application-gateway identity assign", locals())


def remove(gateway_name, resource_group, no_wait=None):
    '''
    Remove the managed service identity of an application-gateway
    '''
    return call_az("az network application-gateway identity remove", locals())


def show(gateway_name, resource_group):
    '''
    Show the managed service identity of an application-gateway
    '''
    return call_az("az network application-gateway identity show", locals())




from .... pyaz_utils import call_az

def add(connection_name, dh_group, ike_encryption, ike_integrity, ipsec_encryption, ipsec_integrity, pfs_group, resource_group, sa_lifetime, sa_max_size, no_wait=None):
    '''
    Add a VPN connection IPSec policy.
    '''
    return call_az("az network vpn-connection ipsec-policy add", locals())


def list(connection_name, resource_group):
    '''
    List IPSec policies associated with a VPN connection.
    '''
    return call_az("az network vpn-connection ipsec-policy list", locals())


def clear(connection_name, resource_group, no_wait=None):
    '''
    Delete all IPsec policies on a VPN connection.
    '''
    return call_az("az network vpn-connection ipsec-policy clear", locals())




from .. pyaz_utils import call_az

def delete(name, resource_group, slot=None, yes=None):
    '''
    Delete a logic app.
    '''
    return call_az("az logicapp delete", locals())


def stop(name, resource_group, slot=None):
    '''
    Stop a logic app.
    '''
    return call_az("az logicapp stop", locals())


def start(name, resource_group, slot=None):
    '''
    Start a logic app.
    '''
    return call_az("az logicapp start", locals())


def restart(name, resource_group, slot=None):
    '''
    Restart a logic app.
    '''
    return call_az("az logicapp restart", locals())


def create(name, resource_group, storage_account, app_insights=None, app_insights_key=None, consumption_plan_location=None, deployment_container_image_name=None, deployment_local_git=None, deployment_source_branch=None, deployment_source_url=None, disable_app_insights=None, docker_registry_server_password=None, docker_registry_server_user=None, os_type=None, plan=None, tags=None):
    '''
    Create a logic app.
    '''
    return call_az("az logicapp create", locals())


def list(resource_group=None):
    '''
    List logic apps.
    '''
    return call_az("az logicapp list", locals())


def show(name, resource_group, slot=None):
    '''
    Get the details of a logic app.
    '''
    return call_az("az logicapp show", locals())




from .... pyaz_utils import call_az

def create(access, communities, filter_name, name, resource_group, location=None):
    '''
    Create a rule in a route filter.
    '''
    return call_az("az network route-filter rule create", locals())


def list(filter_name, resource_group):
    '''
    List rules in a route filter.
    '''
    return call_az("az network route-filter rule list", locals())


def show(filter_name, name, resource_group):
    '''
    Get the details of a rule in a route filter.
    '''
    return call_az("az network route-filter rule show", locals())


def delete(filter_name, name, resource_group):
    '''
    Delete a rule from a route filter.
    '''
    return call_az("az network route-filter rule delete", locals())


def update(filter_name, name, resource_group, add=None, force_string=None, remove=None, set=None):
    '''
    Update a rule in a route filter.
    '''
    return call_az("az network route-filter rule update", locals())


def list_service_communities():
    '''
    Gets all the available BGP service communities.
    '''
    return call_az("az network route-filter rule list-service-communities", locals())




from ... pyaz_utils import call_az

def list(name=None, resource_group=None, slot=None):
    '''
    List web apps that have been deleted.
    '''
    return call_az("az webapp deleted list", locals())


def restore(deleted_id, name, resource_group, restore_content_only=None, slot=None):
    '''
    Restore a deleted web app.
    '''
    return call_az("az webapp deleted restore", locals())




from .... pyaz_utils import call_az

def create(name, resource_group, idle_timeout=None, location=None, no_wait=None, public_ip_addresses=None, public_ip_prefixes=None, zone=None):
    '''
    Create a NAT gateway.
    '''
    return call_az("az network nat gateway create", locals())


def delete(name, resource_group):
    '''
    Delete a NAT gateway.
    '''
    return call_az("az network nat gateway delete", locals())


def list(resource_group=None):
    '''
    List NAT gateways.
    '''
    return call_az("az network nat gateway list", locals())


def show(name, resource_group):
    '''
    Show details of a NAT gateway.
    '''
    return call_az("az network nat gateway show", locals())


def update(name, resource_group, add=None, force_string=None, idle_timeout=None, public_ip_addresses=None, public_ip_prefixes=None, remove=None, set=None):
    '''
    Update a NAT gateway.
    '''
    return call_az("az network nat gateway update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the NAT gateway is met.
    '''
    return call_az("az network nat gateway wait", locals())




from .. pyaz_utils import call_az
from . import account, commitment_tier


def list(resource_group=None):
    '''
    Manage Azure Cognitive Services accounts.
    '''
    return call_az("az cognitiveservices list", locals())




from .... pyaz_utils import call_az

def list(account_name, resource_group):
    '''
    Get the private link resources that need to be created for a storage account.
    '''
    return call_az("az storage account private-link-resource list", locals())




from ... pyaz_utils import call_az

def create(name, provider, resource_group, vhub, location=None, tags=None):
    '''
    Create a Azure security partner provider.
    '''
    return call_az("az network security-partner-provider create", locals())


def update(name, resource_group, add=None, force_string=None, provider=None, remove=None, set=None, tags=None, vhub=None):
    '''
    Update a Azure security partner provider.
    '''
    return call_az("az network security-partner-provider update", locals())


def show(name, resource_group):
    '''
    Show a Azure security partner provider.
    '''
    return call_az("az network security-partner-provider show", locals())


def list(resource_group=None):
    '''
    List all Azure security partner provider.
    '''
    return call_az("az network security-partner-provider list", locals())


def delete(name, resource_group):
    '''
    Delete a Azure security partner provider.
    '''
    return call_az("az network security-partner-provider delete", locals())




from ... pyaz_utils import call_az
from . import event_subscription


def show(name, resource_group):
    '''
    Get the details of a system topic.
    '''
    return call_az("az eventgrid system-topic show", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete a system topic.
    '''
    return call_az("az eventgrid system-topic delete", locals())


def list(odata_query=None, resource_group=None):
    '''
    List available system topics.
    '''
    return call_az("az eventgrid system-topic list", locals())


def create(name, resource_group, source, topic_type, identity=None, location=None, tags=None):
    '''
    Create a system topic.
    '''
    return call_az("az eventgrid system-topic create", locals())


def update(name, resource_group, identity=None, tags=None):
    '''
    Update a system topic.
    '''
    return call_az("az eventgrid system-topic update", locals())




from .. pyaz_utils import call_az
from . import application, availability_set, boot_diagnostics, diagnostics, disk, encryption, extension, host, identity, image, nic, run_command, secret, unmanaged_disk, user


def capture(name, resource_group, vhd_name_prefix, overwrite=None, storage_container=None):
    '''
    Capture information for a stopped VM.
    '''
    return call_az("az vm capture", locals())


def create(name, resource_group, accelerated_networking=None, admin_password=None, admin_username=None, asgs=None, assign_identity=None, attach_data_disks=None, attach_os_disk=None, authentication_type=None, availability_set=None, boot_diagnostics_storage=None, capacity_reservation_group=None, computer_name=None, count=None, custom_data=None, data_disk_caching=None, data_disk_delete_option=None, data_disk_encryption_sets=None, data_disk_sizes_gb=None, edge_zone=None, enable_agent=None, enable_auto_update=None, enable_hibernation=None, enable_hotpatching=None, enable_secure_boot=None, enable_vtpm=None, encryption_at_host=None, ephemeral_os_disk=None, ephemeral_os_disk_placement=None, eviction_policy=None, generate_ssh_keys=None, host=None, host_group=None, image=None, license_type=None, location=None, max_price=None, nic_delete_option=None, nics=None, no_wait=None, nsg=None, nsg_rule=None, os_disk_caching=None, os_disk_delete_option=None, os_disk_encryption_set=None, os_disk_name=None, os_disk_size_gb=None, os_type=None, patch_mode=None, plan_name=None, plan_product=None, plan_promotion_code=None, plan_publisher=None, platform_fault_domain=None, ppg=None, priority=None, private_ip_address=None, public_ip_address=None, public_ip_address_allocation=None, public_ip_address_dns_name=None, public_ip_sku=None, role=None, scope=None, secrets=None, security_type=None, size=None, specialized=None, ssh_dest_key_path=None, ssh_key_name=None, ssh_key_values=None, storage_account=None, storage_container_name=None, storage_sku=None, subnet=None, subnet_address_prefix=None, tags=None, ultra_ssd_enabled=None, use_unmanaged_disk=None, user_data=None, validate=None, vmss=None, vnet_address_prefix=None, vnet_name=None, workspace=None, zone=None):
    '''
    Create an Azure Virtual Machine.
    '''
    return call_az("az vm create", locals())


def convert(name, resource_group):
    '''
    Convert a VM with unmanaged disks to use managed disks.
    '''
    return call_az("az vm convert", locals())


def deallocate(name, resource_group, hibernate=None, no_wait=None):
    '''
    Deallocate a VM.
    '''
    return call_az("az vm deallocate", locals())


def delete(name, resource_group, force_deletion=None, no_wait=None, yes=None):
    '''
    Delete a VM.
    '''
    return call_az("az vm delete", locals())


def generalize(name, resource_group, no_wait=None):
    '''
    Mark a VM as generalized, allowing it to be imaged for multiple deployments.
    '''
    return call_az("az vm generalize", locals())


def get_instance_view(name, resource_group):
    '''
    Get instance information about a VM.
    '''
    return call_az("az vm get-instance-view", locals())


def list(resource_group=None, show_details=None):
    '''
    List details of Virtual Machines.
    '''
    return call_az("az vm list", locals())


def list_ip_addresses(name=None, resource_group=None):
    '''
    List IP addresses associated with a VM.
    '''
    return call_az("az vm list-ip-addresses", locals())


def list_sizes(location):
    '''
    List available sizes for VMs.
    '''
    return call_az("az vm list-sizes", locals())


def list_skus(all=None, location=None, resource_type=None, size=None, zone=None):
    '''
    Get details for compute-related resource SKUs.
    '''
    return call_az("az vm list-skus", locals())


def list_usage(location):
    '''
    List available usage resources for VMs.
    '''
    return call_az("az vm list-usage", locals())


def list_vm_resize_options(name, resource_group):
    '''
    List available resizing options for VMs.
    '''
    return call_az("az vm list-vm-resize-options", locals())


def open_port(name, port, resource_group, apply_to_subnet=None, nsg_name=None, priority=None):
    '''
    Opens a VM to inbound traffic on specified ports.
    '''
    return call_az("az vm open-port", locals())


def perform_maintenance(name, resource_group):
    return call_az("az vm perform-maintenance", locals())


def redeploy(name, resource_group, no_wait=None):
    '''
    Redeploy an existing VM.
    '''
    return call_az("az vm redeploy", locals())


def resize(name, resource_group, size, no_wait=None):
    '''
    Update a VM's size.
    '''
    return call_az("az vm resize", locals())


def restart(name, resource_group, force=None, no_wait=None):
    '''
    Restart VMs.
    '''
    return call_az("az vm restart", locals())


def show(name, resource_group, include_user_data=None, show_details=None):
    '''
    Get the details of a VM.
    '''
    return call_az("az vm show", locals())


def simulate_eviction(name, resource_group):
    '''
    Simulate the eviction of a Spot VM.
    '''
    return call_az("az vm simulate-eviction", locals())


def start(name, resource_group, no_wait=None):
    '''
    Start a stopped VM.
    '''
    return call_az("az vm start", locals())


def stop(name, resource_group, no_wait=None, skip_shutdown=None):
    '''
    Power off (stop) a running VM.
    '''
    return call_az("az vm stop", locals())


def reapply(name, resource_group, no_wait=None):
    '''
    Reapply VMs.
    '''
    return call_az("az vm reapply", locals())


def update(name, resource_group, add=None, capacity_reservation_group=None, disk_caching=None, enable_hibernation=None, enable_secure_boot=None, enable_vtpm=None, ephemeral_os_disk_placement=None, force_string=None, host=None, host_group=None, license_type=None, max_price=None, no_wait=None, os_disk=None, ppg=None, priority=None, remove=None, set=None, size=None, ultra_ssd_enabled=None, user_data=None, workspace=None, write_accelerator=None):
    '''
    Update the properties of a VM.
    '''
    return call_az("az vm update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the VM is met.
    '''
    return call_az("az vm wait", locals())


def auto_shutdown(name, resource_group, email=None, location=None, off=None, time=None, webhook=None):
    '''
    Manage auto-shutdown for VM.
    '''
    return call_az("az vm auto-shutdown", locals())


def assess_patches(name, resource_group):
    '''
    Assess patches on a VM.
    '''
    return call_az("az vm assess-patches", locals())


def install_patches(maximum_duration, name, reboot_setting, resource_group, classifications_to_include_linux=None, classifications_to_include_win=None, exclude_kbs_requiring_reboot=None, kb_numbers_to_exclude=None, kb_numbers_to_include=None, no_wait=None, package_name_masks_to_exclude=None, package_name_masks_to_include=None):
    '''
    Install patches on a VM.
    '''
    return call_az("az vm install-patches", locals())




from .. pyaz_utils import call_az
from . import operation, permission


def list(expand=None):
    return call_az("az provider list", locals())


def show(namespace, expand=None):
    return call_az("az provider show", locals())


def register(namespace, accept_terms=None, consent_to_permissions=None, management_group_id=None, wait=None):
    '''
    Register a provider.
    '''
    return call_az("az provider register", locals())


def unregister(namespace, wait=None):
    '''
    Unregister a provider.
    '''
    return call_az("az provider unregister", locals())




from .... pyaz_utils import call_az

def disable(node_id, pool_id, account_endpoint=None, account_key=None, account_name=None, node_disable_scheduling_option=None):
    return call_az("az batch node scheduling disable", locals())


def enable(node_id, pool_id, account_endpoint=None, account_key=None, account_name=None):
    return call_az("az batch node scheduling enable", locals())




from ... pyaz_utils import call_az

def create(name, principal_id, role_definition_id, tenant_id, definition_id=None, description=None, plan_name=None, plan_product=None, plan_publisher=None, plan_version=None):
    '''
    Creates a new registration definition.
    '''
    return call_az("az managedservices definition create", locals())


def list():
    '''
    List all the registration definitions under the default scope or under the subscription provided.
    '''
    return call_az("az managedservices definition list", locals())


def delete(definition):
    '''
    Deletes a registration.
    '''
    return call_az("az managedservices definition delete", locals())


def show(definition):
    '''
    Gets a registration definition.
    '''
    return call_az("az managedservices definition show", locals())




from ..... pyaz_utils import call_az

def create(data_connection_name, database_name, kusto_pool_name, resource_group, workspace_name, compression=None, consumer_group=None, data_format=None, event_hub_resource_id=None, event_system_properties=None, location=None, managed_identity_resource_id=None, mapping_rule_name=None, no_wait=None, table_name=None):
    '''
    Create a data connection.
    '''
    return call_az("az synapse kusto data-connection event-hub create", locals())


def update(data_connection_name, database_name, kusto_pool_name, resource_group, workspace_name, compression=None, consumer_group=None, data_format=None, event_hub_resource_id=None, event_system_properties=None, location=None, managed_identity_resource_id=None, mapping_rule_name=None, no_wait=None, table_name=None):
    '''
    Updates a data connection.
    '''
    return call_az("az synapse kusto data-connection event-hub update", locals())




from ... pyaz_utils import call_az
from . import credential, identity, timer


def create(name, registry, agent_pool=None, arg=None, assign_identity=None, auth_mode=None, base_image_trigger_enabled=None, base_image_trigger_name=None, base_image_trigger_type=None, commit_trigger_enabled=None, context=None, cpu=None, file=None, git_access_token=None, image=None, is_system_task=None, log_template=None, no_cache=None, no_push=None, platform=None, pull_request_trigger_enabled=None, resource_group=None, schedule=None, secret_arg=None, set=None, set_secret=None, source_trigger_name=None, status=None, target=None, timeout=None, update_trigger_endpoint=None, update_trigger_payload_type=None, values=None):
    '''
    Create a series of steps for building, testing and OS & Framework patching containers. Tasks support triggers from git commits and base image updates.
    '''
    return call_az("az acr task create", locals())


def show(name, registry, resource_group=None, with_secure_properties=None):
    '''
    Get the properties of a named task for an Azure Container Registry.
    '''
    return call_az("az acr task show", locals())


def list(registry, resource_group=None):
    '''
    List the tasks for an Azure Container Registry.
    '''
    return call_az("az acr task list", locals())


def delete(name, registry, resource_group=None, yes=None):
    '''
    Delete a task from an Azure Container Registry.
    '''
    return call_az("az acr task delete", locals())


def update(name, registry, agent_pool=None, arg=None, auth_mode=None, base_image_trigger_enabled=None, base_image_trigger_type=None, commit_trigger_enabled=None, context=None, cpu=None, file=None, git_access_token=None, image=None, log_template=None, no_cache=None, no_push=None, platform=None, pull_request_trigger_enabled=None, resource_group=None, secret_arg=None, set=None, set_secret=None, status=None, target=None, timeout=None, update_trigger_endpoint=None, update_trigger_payload_type=None, values=None):
    '''
    Update a task for an Azure Container Registry.
    '''
    return call_az("az acr task update", locals())


def run(name, registry, agent_pool=None, arg=None, context=None, file=None, log_template=None, no_logs=None, no_wait=None, resource_group=None, secret_arg=None, set=None, set_secret=None, target=None, update_trigger_token=None):
    '''
    Manually trigger a task that might otherwise be waiting for git commits or base image update triggers.
    '''
    return call_az("az acr task run", locals())


def list_runs(registry, image=None, name=None, resource_group=None, run_status=None, top=None):
    '''
    List all of the executed runs for an Azure Container Registry, with the ability to filter by a specific Task.
    '''
    return call_az("az acr task list-runs", locals())


def show_run(registry, run_id, resource_group=None):
    '''
    Get the properties of a specified run of an Azure Container Registry Task.
    '''
    return call_az("az acr task show-run", locals())


def cancel_run(registry, run_id, resource_group=None):
    '''
    Cancel a specified run of an Azure Container Registry.
    '''
    return call_az("az acr task cancel-run", locals())


def update_run(registry, run_id, no_archive=None, resource_group=None):
    '''
    Patch the run properties of an Azure Container Registry Task.
    '''
    return call_az("az acr task update-run", locals())


def logs(registry, image=None, name=None, resource_group=None, run_id=None):
    '''
    Show logs for a particular run. If no run-id is supplied, show logs for the last created run.
    '''
    return call_az("az acr task logs", locals())




from ... pyaz_utils import call_az

def create(file, name, workspace_name, no_wait=None):
    '''
    Create a dataset.
    '''
    return call_az("az synapse dataset create", locals())


def set(file, name, workspace_name, no_wait=None):
    '''
    Update an exist dataset.
    '''
    return call_az("az synapse dataset set", locals())


def update(file, name, workspace_name, no_wait=None):
    '''
    Update an exist dataset.
    '''
    return call_az("az synapse dataset update", locals())


def list(workspace_name):
    '''
    List datasets.
    '''
    return call_az("az synapse dataset list", locals())


def show(name, workspace_name):
    '''
    Get a dataset.
    '''
    return call_az("az synapse dataset show", locals())


def delete(name, workspace_name, no_wait=None, yes=None):
    '''
    Delete a dataset.
    '''
    return call_az("az synapse dataset delete", locals())




from .... pyaz_utils import call_az

def info(name, parent_protocol, registry, resource_group=None):
    '''
    Retrieve information required to activate a connected registry.
    '''
    return call_az("az acr connected-registry install info", locals())


def renew_credentials(name, parent_protocol, registry, resource_group=None, yes=None):
    '''
    Retrieve information required to activate a connected registry, and renews the sync token credentials.
    '''
    return call_az("az acr connected-registry install renew-credentials", locals())




from ... pyaz_utils import call_az
from . import access


def show(account, path):
    '''
    Get file or folder information in a Data Lake Store account.
    '''
    return call_az("az dls fs show", locals())


def list(account, path):
    '''
    List the files and folders in a Data Lake Store account.
    '''
    return call_az("az dls fs list", locals())


def create(account, path, content=None, folder=None, force=None):
    '''
    Creates a file or folder in a Data Lake Store account.
    '''
    return call_az("az dls fs create", locals())


def append(account, content, path):
    '''
    Append content to a file in a Data Lake Store account.
    '''
    return call_az("az dls fs append", locals())


def delete(account, path, recurse=None):
    '''
    Delete a file or folder in a Data Lake Store account.
    '''
    return call_az("az dls fs delete", locals())


def upload(account, destination_path, source_path, block_size=None, buffer_size=None, chunk_size=None, overwrite=None, thread_count=None):
    '''
    Upload a file or folder to a Data Lake Store account.
    '''
    return call_az("az dls fs upload", locals())


def download(account, destination_path, source_path, block_size=None, buffer_size=None, chunk_size=None, overwrite=None, thread_count=None):
    '''
    Download a file or folder from a Data Lake Store account to the local machine.
    '''
    return call_az("az dls fs download", locals())


def test(account, path):
    '''
    Test for the existence of a file or folder in a Data Lake Store account.
    '''
    return call_az("az dls fs test", locals())


def preview(account, path, force=None, length=None, offset=None):
    '''
    Preview the content of a file in a Data Lake Store account.
    '''
    return call_az("az dls fs preview", locals())


def join(account, destination_path, source_paths, force=None):
    '''
    Join files in a Data Lake Store account into one file.
    '''
    return call_az("az dls fs join", locals())


def move(account, destination_path, source_path, force=None):
    '''
    Move a file or folder in a Data Lake Store account.
    '''
    return call_az("az dls fs move", locals())


def set_expiry(account, expiration_time, path):
    '''
    Set the expiration time for a file.
    '''
    return call_az("az dls fs set-expiry", locals())


def remove_expiry(account, path):
    '''
    Remove the expiration time for a file.
    '''
    return call_az("az dls fs remove-expiry", locals())




from ... pyaz_utils import call_az
from . import container, database, restorable_container, restorable_database, restorable_resource, stored_procedure, trigger, user_defined_function


def retrieve_latest_backup_time(account_name, container_name, database_name, location, resource_group):
    '''
    Retrieves latest restorable timestamp for the given sql container in given region.
    '''
    return call_az("az cosmosdb sql retrieve-latest-backup-time", locals())




from ... pyaz_utils import call_az

def create(client_id, client_secret, name, resource_group, verification_token, add_disabled=None, landing_page_url=None):
    '''
    Create the Slack Channel on a bot.
    '''
    return call_az("az bot slack create", locals())


def show(name, resource_group, with_secrets=None):
    '''
    Get details of the Slack Channel on a bot
    '''
    return call_az("az bot slack show", locals())


def delete(name, resource_group):
    '''
    Delete the Slack Channel on a bot
    '''
    return call_az("az bot slack delete", locals())




from .... pyaz_utils import call_az

def create(end_ip_address, name, resource_group, server_name, start_ip_address):
    '''
    Create a new firewall rule for a server.
    '''
    return call_az("az postgres server firewall-rule create", locals())


def delete(name, resource_group, server_name, yes=None):
    '''
    Delete a firewall rule.
    '''
    return call_az("az postgres server firewall-rule delete", locals())


def show(name, resource_group, server_name):
    '''
    Get the details of a firewall rule.
    '''
    return call_az("az postgres server firewall-rule show", locals())


def list(resource_group, server_name):
    '''
    List all firewall rules for a server.
    '''
    return call_az("az postgres server firewall-rule list", locals())


def update(name, resource_group, server_name, add=None, end_ip_address=None, force_string=None, remove=None, set=None, start_ip_address=None):
    '''
    Update a firewall rule.
    '''
    return call_az("az postgres server firewall-rule update", locals())




from ... pyaz_utils import call_az

def list():
    '''
    list of all possible traffic between resources for the subscription.
    '''
    return call_az("az security allowed_connections list", locals())


def show(name, resource_group):
    '''
    List all possible traffic between resources for the subscription and location, based on connection type.
    '''
    return call_az("az security allowed_connections show", locals())




from ... pyaz_utils import call_az

def disable(name, resource_group):
    '''
    Disable the boot diagnostics on a VM.
    '''
    return call_az("az vm boot-diagnostics disable", locals())


def enable(name, resource_group, storage=None):
    '''
    Enable the boot diagnostics on a VM.
    '''
    return call_az("az vm boot-diagnostics enable", locals())


def get_boot_log(name, resource_group):
    '''
    Get the boot diagnostics log from a VM.
    '''
    return call_az("az vm boot-diagnostics get-boot-log", locals())


def get_boot_log_uris(name, resource_group, expire=None):
    '''
    Get SAS URIs for a virtual machine's boot diagnostic logs.
    '''
    return call_az("az vm boot-diagnostics get-boot-log-uris", locals())




from .... pyaz_utils import call_az

def add(external_mappings, gateway_name, internal_mappings, name, resource_group, ip_config_id=None, mode=None, no_wait=None, type=None):
    '''
    Add nat rule in a virtual network gateway
    '''
    return call_az("az network vnet-gateway nat-rule add", locals())


def list(gateway_name, resource_group):
    '''
    List nat rule for a virtual network gateway
    '''
    return call_az("az network vnet-gateway nat-rule list", locals())


def remove(gateway_name, name, resource_group, no_wait=None):
    '''
    Remove nat rule from a virtual network gateway
    '''
    return call_az("az network vnet-gateway nat-rule remove", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the vnet gateway nat rule is met.
    '''
    return call_az("az network vnet-gateway nat-rule wait", locals())




from ... pyaz_utils import call_az
from . import access, directory, file, metadata


def create(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, metadata=None, public_access=None, sas_token=None, timeout=None):
    '''
    Create file system for Azure Data Lake Storage Gen2 account.
    '''
    return call_az("az storage fs create", locals())


def list(account_key=None, account_name=None, auth_mode=None, connection_string=None, include_metadata=None, prefix=None, sas_token=None):
    '''
    List file systems in ADLS Gen2 account.
    '''
    return call_az("az storage fs list", locals())


def show(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Show properties of file system in ADLS Gen2 account.
    '''
    return call_az("az storage fs show", locals())


def delete(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None, yes=None):
    '''
    Delete a file system in ADLS Gen2 account.
    '''
    return call_az("az storage fs delete", locals())


def exists(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Check for the existence of a file system in ADLS Gen2 account.
    '''
    return call_az("az storage fs exists", locals())


def generate_sas(name, account_key=None, account_name=None, as_user=None, auth_mode=None, cache_control=None, connection_string=None, content_disposition=None, content_encoding=None, content_language=None, content_type=None, expiry=None, full_uri=None, https_only=None, ip=None, permissions=None, policy_name=None, start=None):
    '''
    Generate a SAS token for file system in ADLS Gen2 account.
    '''
    return call_az("az storage fs generate-sas", locals())




from ... pyaz_utils import call_az

def set(resource_group, settings, vm_name, no_auto_upgrade_minor_version=None, protected_settings=None, version=None):
    '''
    Configure the Azure VM diagnostics extension.
    '''
    return call_az("az vm diagnostics set", locals())


def get_default_config(is_windows_os=None):
    '''
    Get the default configuration settings for a VM.
    '''
    return call_az("az vm diagnostics get-default-config", locals())




from ... pyaz_utils import call_az

def list(resource_group, server_name, file_last_written=None, filename_contains=None, max_file_size=None):
    '''
    List log files for a server.
    '''
    return call_az("az mysql server-logs list", locals())


def download(name, resource_group, server_name):
    '''
    Download log files.
    '''
    return call_az("az mysql server-logs download", locals())




from .... pyaz_utils import call_az
from . import keys


def create(eventhub_name, name, namespace_name, resource_group, rights=None):
    '''
    Creates Authorizationrule for the given Eventhub
    '''
    return call_az("az eventhubs eventhub authorization-rule create", locals())


def show(eventhub_name, name, namespace_name, resource_group):
    '''
    shows the details of Authorizationrule
    '''
    return call_az("az eventhubs eventhub authorization-rule show", locals())


def list(eventhub_name, namespace_name, resource_group):
    '''
    shows the list of Authorization-rules by Eventhub
    '''
    return call_az("az eventhubs eventhub authorization-rule list", locals())


def delete(eventhub_name, name, namespace_name, resource_group):
    '''
    Deletes the Authorizationrule of Eventhub.
    '''
    return call_az("az eventhubs eventhub authorization-rule delete", locals())


def update(eventhub_name, name, namespace_name, resource_group, rights, add=None, force_string=None, remove=None, set=None):
    '''
    Updates Authorizationrule for the given Eventhub
    '''
    return call_az("az eventhubs eventhub authorization-rule update", locals())




from .... pyaz_utils import call_az

def list(lb_name, resource_group):
    '''
    List frontend IP addresses.
    '''
    return call_az("az network lb frontend-ip list", locals())


def show(lb_name, name, resource_group):
    '''
    Get the details of a frontend IP address.
    '''
    return call_az("az network lb frontend-ip show", locals())


def delete(lb_name, name, resource_group):
    '''
    Delete a frontend IP address.
    '''
    return call_az("az network lb frontend-ip delete", locals())


def create(lb_name, name, resource_group, private_ip_address=None, private_ip_address_version=None, public_ip_address=None, public_ip_prefix=None, subnet=None, vnet_name=None, zone=None):
    '''
    Create a frontend IP address.
    '''
    return call_az("az network lb frontend-ip create", locals())


def update(lb_name, name, resource_group, add=None, force_string=None, gateway_lb=None, private_ip_address=None, public_ip_address=None, public_ip_prefix=None, remove=None, set=None, subnet=None, vnet_name=None):
    '''
    Update a frontend IP address.
    '''
    return call_az("az network lb frontend-ip update", locals())




from ... pyaz_utils import call_az

def show(lab_name, name, resource_group, expand=None):
    '''
    Get the details for an environment of a lab.
    '''
    return call_az("az lab environment show", locals())


def list(lab_name, resource_group, expand=None, filter=None, orderby=None, top=None):
    '''
    List environments in a lab.
    '''
    return call_az("az lab environment list", locals())


def delete(lab_name, name, resource_group):
    '''
    Delete an environment from a lab.
    '''
    return call_az("az lab environment delete", locals())


def create(arm_template, lab_name, name, resource_group, artifact_source_name=None, parameters=None, tags=None):
    '''
    Create an environment in a lab.
    '''
    return call_az("az lab environment create", locals())




from .. pyaz_utils import call_az

def create(master_subnet, name, resource_group, worker_subnet, apiserver_visibility=None, client_id=None, client_secret=None, cluster_resource_group=None, domain=None, ingress_visibility=None, location=None, master_vm_size=None, no_wait=None, pod_cidr=None, pull_secret=None, service_cidr=None, tags=None, vnet=None, vnet_resource_group=None, worker_count=None, worker_vm_disk_size_gb=None, worker_vm_size=None):
    '''
    Create a cluster.
    '''
    return call_az("az aro create", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Delete a cluster.
    '''
    return call_az("az aro delete", locals())


def list(resource_group=None):
    '''
    List clusters.
    '''
    return call_az("az aro list", locals())


def show(name, resource_group):
    '''
    Get the details of a cluster.
    '''
    return call_az("az aro show", locals())


def update(name, resource_group, client_id=None, client_secret=None, no_wait=None, refresh_credentials=None):
    '''
    Update a cluster.
    '''
    return call_az("az aro update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Wait for a cluster to reach a desired state.
    '''
    return call_az("az aro wait", locals())


def list_credentials(name, resource_group):
    '''
    List credentials of a cluster.
    '''
    return call_az("az aro list-credentials", locals())




from .. pyaz_utils import call_az

def add(index=None, name=None, pip_extra_index_urls=None, pip_proxy=None, source=None, system=None, upgrade=None, version=None, yes=None):
    '''
    Add an extension.
    '''
    return call_az("az extension add", locals())


def remove(name):
    '''
    Remove an extension.
    '''
    return call_az("az extension remove", locals())


def list():
    '''
    List the installed extensions.
    '''
    return call_az("az extension list", locals())


def show(name):
    '''
    Show an extension.
    '''
    return call_az("az extension show", locals())


def list_available(index=None, show_details=None):
    '''
    List publicly available extensions.
    '''
    return call_az("az extension list-available", locals())


def update(name, index=None, pip_extra_index_urls=None, pip_proxy=None):
    '''
    Update an extension.
    '''
    return call_az("az extension update", locals())


def list_versions(name, index=None):
    '''
    List available versions for an extension.
    '''
    return call_az("az extension list-versions", locals())




from ..... pyaz_utils import call_az

def list(name, namespace_name, queue_name, resource_group):
    '''
    List the keys and connection strings of Authorization Rule for the given Service Bus Queue
    '''
    return call_az("az servicebus queue authorization-rule keys list", locals())


def renew(name, namespace_name, queue_name, resource_group, key=None, key_value=None):
    '''
    Regenerate keys of Authorization Rule for Service Bus Queue
    '''
    return call_az("az servicebus queue authorization-rule keys renew", locals())




from ... pyaz_utils import call_az

def query(table_name, accept=None, account_key=None, account_name=None, connection_string=None, filter=None, marker=None, num_results=None, sas_token=None, select=None, timeout=None):
    '''
    List entities which satisfy a query.
    '''
    return call_az("az storage entity query", locals())


def replace(entity, table_name, account_key=None, account_name=None, connection_string=None, if_match=None, sas_token=None, timeout=None):
    return call_az("az storage entity replace", locals())


def merge(entity, table_name, account_key=None, account_name=None, connection_string=None, if_match=None, sas_token=None, timeout=None):
    return call_az("az storage entity merge", locals())


def delete(partition_key, row_key, table_name, account_key=None, account_name=None, connection_string=None, if_match=None, sas_token=None, timeout=None):
    return call_az("az storage entity delete", locals())


def show(partition_key, row_key, table_name, accept=None, account_key=None, account_name=None, connection_string=None, sas_token=None, select=None, timeout=None):
    return call_az("az storage entity show", locals())


def insert(entity, table_name, account_key=None, account_name=None, connection_string=None, if_exists=None, sas_token=None, timeout=None):
    '''
    Insert an entity into a table.
    '''
    return call_az("az storage entity insert", locals())




from ... pyaz_utils import call_az
from . import ip_config


def create(name, resource_group, subnet, accelerated_networking=None, app_gateway_address_pools=None, application_security_groups=None, dns_servers=None, edge_zone=None, gateway_name=None, internal_dns_name=None, ip_forwarding=None, lb_address_pools=None, lb_inbound_nat_rules=None, lb_name=None, location=None, network_security_group=None, no_wait=None, private_ip_address=None, private_ip_address_version=None, public_ip_address=None, tags=None, vnet_name=None):
    '''
    Create a network interface.
    '''
    return call_az("az network nic create", locals())


def delete(name, resource_group, no_wait=None):
    '''
    Delete a network interface.
    '''
    return call_az("az network nic delete", locals())


def show(name, resource_group, expand=None):
    '''
    Get the details of a network interface.
    '''
    return call_az("az network nic show", locals())


def list(resource_group=None):
    '''
    List network interfaces.
    '''
    return call_az("az network nic list", locals())


def show_effective_route_table(name, resource_group):
    '''
    Show the effective route table applied to a network interface.
    '''
    return call_az("az network nic show-effective-route-table", locals())


def list_effective_nsg(name, resource_group):
    '''
    List all effective network security groups applied to a network interface.
    '''
    return call_az("az network nic list-effective-nsg", locals())


def update(name, resource_group, accelerated_networking=None, add=None, dns_servers=None, force_string=None, internal_dns_name=None, ip_forwarding=None, network_security_group=None, no_wait=None, remove=None, set=None):
    '''
    Update a network interface.
    '''
    return call_az("az network nic update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, expand=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the network interface is met.
    '''
    return call_az("az network nic wait", locals())




from .... pyaz_utils import call_az

def delete(name, registry, password1=None, password2=None, resource_group=None):
    '''
    Delete a token credential.
    '''
    return call_az("az acr token credential delete", locals())


def generate(name, registry, expiration=None, expiration_in_days=None, password1=None, password2=None, resource_group=None):
    '''
    Generate or replace one or both passwords of a token for an Azure Container Registry. For using token and password to access a container registry, see https://aka.ms/acr/repo-permissions.
    '''
    return call_az("az acr token credential generate", locals())




from .... pyaz_utils import call_az

def set(cluster_name, resource_group, upgrade_mode, version=None):
    '''
    Change the  upgrade type for a cluster.
    '''
    return call_az("az sf cluster upgrade-type set", locals())




from .... pyaz_utils import call_az

def list(experiment, job, resource_group, workspace, expiry=None, output_directory_id=None, path=None):
    '''
    List job's output files in a directory with given id.
    '''
    return call_az("az batchai job file list", locals())


def stream(experiment, file_name, job, resource_group, workspace, output_directory_id=None, path=None):
    '''
    Stream the content of a file (similar to 'tail -f').
    '''
    return call_az("az batchai job file stream", locals())




from .... pyaz_utils import call_az

def download(destination, node_id, pool_id, account_endpoint=None, account_key=None, account_name=None):
    return call_az("az batch node remote-desktop download", locals())




from .... pyaz_utils import call_az

def list(api_id, resource_group, service_name):
    '''
    List a collection of the operations for the specified API.
    '''
    return call_az("az apim api operation list", locals())


def show(api_id, operation_id, resource_group, service_name):
    '''
    Gets the details of the API Operation specified by its identifier.
    '''
    return call_az("az apim api operation show", locals())


def create(api_id, display_name, method, resource_group, service_name, url_template, description=None, if_match=None, operation_id=None, template_parameters=None):
    '''
    Creates a new operation in the API
    '''
    return call_az("az apim api operation create", locals())


def update(api_id, operation_id, resource_group, service_name, add=None, description=None, display_name=None, force_string=None, if_match=None, method=None, remove=None, set=None, url_template=None):
    '''
    Updates the details of the operation in the API specified by its identifier.
    '''
    return call_az("az apim api operation update", locals())


def delete(api_id, operation_id, resource_group, service_name, if_match=None):
    '''
    Deletes the specified operation in the API.
    '''
    return call_az("az apim api operation delete", locals())




from .... pyaz_utils import call_az

def show(registry, resource_group=None):
    '''
    Show the configured content-trust policy for an Azure Container Registry.
    '''
    return call_az("az acr config content-trust show", locals())


def update(registry, resource_group=None, status=None):
    '''
    Update content-trust policy for an Azure Container Registry.
    '''
    return call_az("az acr config content-trust update", locals())




from ... pyaz_utils import call_az

def approve(description=None, id=None, name=None, resource_group=None, resource_name=None, type=None):
    '''
    Approve a private endpoint connection.
    '''
    return call_az("az network private-endpoint-connection approve", locals())


def reject(description=None, id=None, name=None, resource_group=None, resource_name=None, type=None):
    '''
    Reject a private endpoint connection.
    '''
    return call_az("az network private-endpoint-connection reject", locals())


def delete(id=None, name=None, resource_group=None, resource_name=None, type=None, yes=None):
    '''
    Delete a private endpoint connection.
    '''
    return call_az("az network private-endpoint-connection delete", locals())


def show(id=None, name=None, resource_group=None, resource_name=None, type=None):
    '''
    Show a private endpoint connection.
    '''
    return call_az("az network private-endpoint-connection show", locals())


def list(id=None, name=None, resource_group=None, type=None):
    '''
    List all private endpoint connections.
    '''
    return call_az("az network private-endpoint-connection list", locals())




from ... pyaz_utils import call_az

def create(name, resource_group, server_name, charset=None, collation=None):
    '''
    Create a MariaDB database.
    '''
    return call_az("az mariadb db create", locals())


def delete(name, resource_group, server_name, yes=None):
    '''
    Delete a database.
    '''
    return call_az("az mariadb db delete", locals())


def show(name, resource_group, server_name):
    '''
    Show the details of a database.
    '''
    return call_az("az mariadb db show", locals())


def list(resource_group, server_name):
    '''
    List the databases for a server.
    '''
    return call_az("az mariadb db list", locals())




from .... pyaz_utils import call_az

def set(name, resource_group, server, monthly_retention=None, week_of_year=None, weekly_retention=None, yearly_retention=None):
    '''
    Update long term retention settings for a database.
    '''
    return call_az("az sql db ltr-policy set", locals())


def show(name, resource_group, server):
    '''
    Show the long term retention policy for a database.
    '''
    return call_az("az sql db ltr-policy show", locals())




from ... pyaz_utils import call_az
from . import ad_admin, ad_only_auth, key, op, tde_key


def create(name, resource_group, subnet, admin_password=None, admin_user=None, assign_identity=None, backup_storage_redundancy=None, capacity=None, collation=None, enable_ad_only_auth=None, external_admin_name=None, external_admin_principal_type=None, external_admin_sid=None, family=None, identity_type=None, key_id=None, license_type=None, location=None, maint_config_id=None, minimal_tls_version=None, no_wait=None, primary_user_assigned_identity_id=None, proxy_override=None, public_data_endpoint_enabled=None, storage=None, tags=None, tier=None, timezone_id=None, user_assigned_identity_id=None, vnet_name=None, yes=None):
    '''
    Create a managed instance.
    '''
    return call_az("az sql mi create", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Delete a managed instance.
    '''
    return call_az("az sql mi delete", locals())


def show(name, resource_group, expand_ad_admin=None):
    '''
    Get the details for a managed instance.
    '''
    return call_az("az sql mi show", locals())


def list(expand_ad_admin=None, resource_group=None):
    '''
    List available managed instances.
    '''
    return call_az("az sql mi list", locals())


def update(name, resource_group, add=None, admin_password=None, assign_identity=None, capacity=None, family=None, force_string=None, identity_type=None, key_id=None, license_type=None, maint_config_id=None, minimal_tls_version=None, no_wait=None, primary_user_assigned_identity_id=None, proxy_override=None, public_data_endpoint_enabled=None, remove=None, set=None, storage=None, subnet=None, tags=None, tier=None, user_assigned_identity_id=None, vnet_name=None):
    '''
    Update a managed instance.
    '''
    return call_az("az sql mi update", locals())


def failover(name, resource_group, no_wait=None, replica_type=None):
    '''
    Failover a managed instance.
    '''
    return call_az("az sql mi failover", locals())




from ..... pyaz_utils import call_az

def list(name, resource_group, server, filter=None, include_disabled_recommendations=None):
    '''
    List the recommended sensitivity classifications of a given database.
    '''
    return call_az("az sql db classification recommendation list", locals())


def enable(column, name, resource_group, schema, server, table):
    '''
    Enable sensitivity recommendations for a given column (recommendations are enabled by default on all columns).
    '''
    return call_az("az sql db classification recommendation enable", locals())


def disable(column, name, resource_group, schema, server, table):
    '''
    Disable sensitivity recommendations for a given column (recommendations are enabled by default on all columns).
    '''
    return call_az("az sql db classification recommendation disable", locals())




from .... pyaz_utils import call_az

def show(account_name, resource_group, snapshot_policy_name):
    '''
    Get the specified ANF snapshot policy.
    '''
    return call_az("az netappfiles snapshot policy show", locals())


def list(account_name, resource_group):
    '''
    List the ANF snapshot policies for the specified account.
    '''
    return call_az("az netappfiles snapshot policy list", locals())


def volumes(account_name, resource_group, snapshot_policy_name):
    '''
    Get the all ANF volumes associated with snapshot policy.
    '''
    return call_az("az netappfiles snapshot policy volumes", locals())


def delete(account_name, resource_group, snapshot_policy_name):
    '''
    Delete the specified ANF snapshot policy.
    '''
    return call_az("az netappfiles snapshot policy delete", locals())


def update(account_name, location, resource_group, snapshot_policy_name, daily_hour=None, daily_minute=None, daily_snapshots=None, enabled=None, hourly_minute=None, hourly_snapshots=None, monthly_days=None, monthly_hour=None, monthly_minute=None, monthly_snapshots=None, weekly_day=None, weekly_hour=None, weekly_minute=None, weekly_snapshots=None):
    '''
    Update the specified ANF snapshot policy.
    '''
    return call_az("az netappfiles snapshot policy update", locals())


def create(account_name, location, resource_group, snapshot_policy_name, daily_hour=None, daily_minute=None, daily_snapshots=None, enabled=None, hourly_minute=None, hourly_snapshots=None, monthly_days=None, monthly_hour=None, monthly_minute=None, monthly_snapshots=None, tags=None, weekly_day=None, weekly_hour=None, weekly_minute=None, weekly_snapshots=None):
    '''
    Create a new Azure NetApp Files (ANF) snapshot policy.
    '''
    return call_az("az netappfiles snapshot policy create", locals())




from ... pyaz_utils import call_az

def show(origin_group_name, profile_name, resource_group):
    return call_az("az afd origin-group show", locals())


def list(profile_name, resource_group):
    return call_az("az afd origin-group list", locals())


def create(additional_latency_in_milliseconds, origin_group_name, probe_path, probe_protocol, probe_request_type, profile_name, resource_group, sample_size, successful_samples_required, probe_interval_in_seconds=None):
    '''
    Creates a new origin group within the specified profile.
    '''
    return call_az("az afd origin-group create", locals())


def update(origin_group_name, profile_name, resource_group, additional_latency_in_milliseconds=None, probe_interval_in_seconds=None, probe_path=None, probe_protocol=None, probe_request_type=None, sample_size=None, successful_samples_required=None):
    '''
    Creates a new origin group within the specified profile.
    '''
    return call_az("az afd origin-group update", locals())


def delete(origin_group_name, profile_name, resource_group, yes=None):
    '''
    Deletes an existing origin group within the specified profile.
    '''
    return call_az("az afd origin-group delete", locals())




from ...... pyaz_utils import call_az

def set(address_prefix, circuit_name, name, peering_name, resource_group):
    '''
    Set connection config to ExpressRoute circuit connection.
    '''
    return call_az("az network express-route peering connection ipv6-config set", locals())


def remove(circuit_name, name, peering_name, resource_group):
    '''
    Remove connection config to ExpressRoute circuit connection.
    '''
    return call_az("az network express-route peering connection ipv6-config remove", locals())




from ... pyaz_utils import call_az

def list(resource_group):
    return call_az("az search service list", locals())


def show(name, resource_group):
    return call_az("az search service show", locals())


def delete(name, resource_group, yes=None):
    return call_az("az search service delete", locals())


def update(name, resource_group, add=None, force_string=None, identity_type=None, ip_rules=None, no_wait=None, partition_count=None, public_network_access=None, remove=None, replica_count=None, set=None):
    '''
    Update partition and replica of the given search service.
    '''
    return call_az("az search service update", locals())


def create(name, resource_group, sku, identity_type=None, ip_rules=None, location=None, no_wait=None, partition_count=None, public_network_access=None, replica_count=None):
    '''
    Creates a Search service in the given resource group.
    '''
    return call_az("az search service create", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Wait for async service operations.
    '''
    return call_az("az search service wait", locals())




from .... pyaz_utils import call_az

def set(name, resource_group, server_name, source=None, value=None):
    '''
    Update the parameter of a flexible server.
    '''
    return call_az("az postgres flexible-server parameter set", locals())


def show(name, resource_group, server_name):
    '''
    Get the parameter for a flexible server."
    '''
    return call_az("az postgres flexible-server parameter show", locals())


def list(resource_group, server_name):
    '''
    List the parameter values for a flexible server.
    '''
    return call_az("az postgres flexible-server parameter list", locals())




from .... pyaz_utils import call_az

def add(login_server, name, registry, password=None, resource_group=None, use_identity=None, username=None):
    '''
    Add a custom registry login credential to the task
    '''
    return call_az("az acr task credential add", locals())


def update(login_server, name, registry, password=None, resource_group=None, use_identity=None, username=None):
    '''
    Update the registry login credential for a task.
    '''
    return call_az("az acr task credential update", locals())


def remove(login_server, name, registry, resource_group=None):
    '''
    Remove credential for a task.
    '''
    return call_az("az acr task credential remove", locals())


def list(name, registry, resource_group=None):
    '''
    List all the custom registry credentials for task.
    '''
    return call_az("az acr task credential list", locals())




from ... pyaz_utils import call_az

def list(device_name, resource_group):
    '''
    List all the orders related to a Data Box Edge/Data Box Gateway device.
    '''
    return call_az("az databoxedge order list", locals())


def show(device_name, resource_group):
    '''
    Get a specific order by name.
    '''
    return call_az("az databoxedge order show", locals())


def create(address_line1, city, company_name, contact_person, country, device_name, email_list, phone, postal_code, resource_group, state, status, address_line2=None, address_line3=None, comments=None, no_wait=None):
    '''
    Create an order.
    '''
    return call_az("az databoxedge order create", locals())


def update(device_name, resource_group, add=None, address_line1=None, address_line2=None, address_line3=None, city=None, comments=None, company_name=None, contact_person=None, country=None, email_list=None, force_string=None, no_wait=None, phone=None, postal_code=None, remove=None, set=None, state=None, status=None):
    '''
    Update an order.
    '''
    return call_az("az databoxedge order update", locals())


def delete(device_name, resource_group, no_wait=None, yes=None):
    '''
    Delete the order related to the device.
    '''
    return call_az("az databoxedge order delete", locals())


def wait(device_name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the databoxedge order is met.
    '''
    return call_az("az databoxedge order wait", locals())




from ... pyaz_utils import call_az

def list(resource_group=None):
    '''
    List security tasks (recommendations).
    '''
    return call_az("az security task list", locals())


def show(name, resource_group=None):
    '''
    shows a security task (recommendation).
    '''
    return call_az("az security task show", locals())




from ... pyaz_utils import call_az
from . import file, node


def create(name, resource_group, workspace, afs_mount_path=None, afs_name=None, bfs_mount_path=None, bfs_name=None, config_file=None, custom_image=None, generate_ssh_keys=None, image=None, max=None, min=None, nfs=None, nfs_mount_path=None, password=None, setup_task=None, setup_task_output=None, ssh_key=None, storage_account_key=None, storage_account_name=None, subnet=None, target=None, use_auto_storage=None, user_name=None, vm_priority=None, vm_size=None):
    '''
    Create a cluster.
    '''
    return call_az("az batchai cluster create", locals())


def delete(name, resource_group, workspace, no_wait=None, yes=None):
    '''
    Delete a cluster.
    '''
    return call_az("az batchai cluster delete", locals())


def show(name, resource_group, workspace):
    '''
    Show information about a cluster.
    '''
    return call_az("az batchai cluster show", locals())


def list(resource_group, workspace):
    '''
    List clusters.
    '''
    return call_az("az batchai cluster list", locals())


def resize(name, resource_group, target, workspace):
    '''
    Resize a cluster.
    '''
    return call_az("az batchai cluster resize", locals())


def auto_scale(max, min, name, resource_group, workspace):
    '''
    Set auto-scale parameters for a cluster.
    '''
    return call_az("az batchai cluster auto-scale", locals())




from .... pyaz_utils import call_az
from . import throughput


def create(account_name, database_name, name, resource_group, analytical_storage_ttl=None, idx=None, max_throughput=None, shard=None, throughput=None):
    '''
    Create an MongoDB collection under an Azure Cosmos DB MongoDB database.
    '''
    return call_az("az cosmosdb mongodb collection create", locals())


def update(account_name, database_name, name, resource_group, analytical_storage_ttl=None, idx=None):
    '''
    Update an MongoDB collection under an Azure Cosmos DB MongoDB database.
    '''
    return call_az("az cosmosdb mongodb collection update", locals())


def exists(account_name, database_name, name, resource_group):
    return call_az("az cosmosdb mongodb collection exists", locals())


def list(account_name, database_name, resource_group):
    '''
    List the MongoDB collections under an Azure Cosmos DB MongoDB database.
    '''
    return call_az("az cosmosdb mongodb collection list", locals())


def show(account_name, database_name, name, resource_group):
    '''
    Show the details of a MongoDB collection under an Azure Cosmos DB MongoDB database.
    '''
    return call_az("az cosmosdb mongodb collection show", locals())


def delete(account_name, database_name, name, resource_group, yes=None):
    '''
    Delete the MongoDB collection under an Azure Cosmos DB MongoDB database.
    '''
    return call_az("az cosmosdb mongodb collection delete", locals())




from ... pyaz_utils import call_az
from . import all_statistics, autoscale, node_counts, supported_images, usage_metrics


def create(account_endpoint=None, account_key=None, account_name=None, application_licenses=None, application_package_references=None, auto_scale_formula=None, certificate_references=None, disk_encryption_targets=None, enable_inter_node_communication=None, id=None, image=None, json_file=None, metadata=None, node_agent_sku_id=None, offer=None, os_family=None, os_version=None, policy=None, publisher=None, resize_timeout=None, sku=None, start_task_command_line=None, start_task_resource_files=None, start_task_wait_for_success=None, target_dedicated_nodes=None, target_low_priority_nodes=None, targets=None, task_slots_per_node=None, version=None, virtual_machine_image_id=None, vm_size=None):
    '''
    Create a Batch pool in an account. When creating a pool, choose arguments from either Cloud Services Configuration or Virtual Machine Configuration.
    '''
    return call_az("az batch pool create", locals())


def list(account_endpoint=None, account_key=None, account_name=None, expand=None, filter=None, select=None):
    return call_az("az batch pool list", locals())


def delete(pool_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, yes=None):
    return call_az("az batch pool delete", locals())


def show(pool_id, account_endpoint=None, account_key=None, account_name=None, expand=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, select=None):
    return call_az("az batch pool show", locals())


def set(pool_id, account_endpoint=None, account_key=None, account_name=None, application_package_references=None, certificate_references=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, json_file=None, metadata=None, start_task_command_line=None, start_task_environment_settings=None, start_task_max_task_retry_count=None, start_task_resource_files=None, start_task_wait_for_success=None):
    '''
    Update the properties of a Batch pool. Updating a property in a subgroup will reset the unspecified properties of that group.
    '''
    return call_az("az batch pool set", locals())


def reset(pool_id, account_endpoint=None, account_key=None, account_name=None, application_package_references=None, certificate_references=None, json_file=None, metadata=None, start_task_command_line=None, start_task_environment_settings=None, start_task_max_task_retry_count=None, start_task_wait_for_success=None):
    '''
    Update the properties of a Batch pool. Unspecified properties which can be updated are reset to their defaults.
    '''
    return call_az("az batch pool reset", locals())


def resize(pool_id, abort=None, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, node_deallocation_option=None, resize_timeout=None, target_dedicated_nodes=None, target_low_priority_nodes=None):
    '''
    Resize or stop resizing a Batch pool.
    '''
    return call_az("az batch pool resize", locals())




from .. pyaz_utils import call_az
from . import application, diagnostics, disk, encryption, extension, identity, nic, rolling_upgrade, run_command


def create(name, resource_group, accelerated_networking=None, admin_password=None, admin_username=None, app_gateway=None, app_gateway_capacity=None, app_gateway_sku=None, app_gateway_subnet_address_prefix=None, asgs=None, assign_identity=None, authentication_type=None, automatic_repairs_grace_period=None, backend_pool_name=None, backend_port=None, capacity_reservation_group=None, computer_name_prefix=None, custom_data=None, data_disk_caching=None, data_disk_encryption_sets=None, data_disk_iops=None, data_disk_mbps=None, data_disk_sizes_gb=None, disable_overprovision=None, dns_servers=None, edge_zone=None, enable_agent=None, enable_auto_update=None, enable_cross_zone_upgrade=None, enable_spot_restore=None, encryption_at_host=None, ephemeral_os_disk=None, ephemeral_os_disk_placement=None, eviction_policy=None, generate_ssh_keys=None, health_probe=None, host_group=None, image=None, instance_count=None, lb_nat_pool_name=None, lb_sku=None, license_type=None, load_balancer=None, location=None, max_batch_instance_percent=None, max_price=None, max_unhealthy_instance_percent=None, max_unhealthy_upgraded_instance_percent=None, network_api_version=None, no_wait=None, nsg=None, orchestration_mode=None, os_disk_caching=None, os_disk_encryption_set=None, os_disk_name=None, os_disk_size_gb=None, os_type=None, patch_mode=None, pause_time_between_batches=None, plan_name=None, plan_product=None, plan_promotion_code=None, plan_publisher=None, platform_fault_domain_count=None, ppg=None, prioritize_unhealthy_instances=None, priority=None, public_ip_address=None, public_ip_address_allocation=None, public_ip_address_dns_name=None, public_ip_per_vm=None, role=None, scale_in_policy=None, scope=None, secrets=None, single_placement_group=None, specialized=None, spot_restore_timeout=None, ssh_dest_key_path=None, ssh_key_values=None, storage_container_name=None, storage_sku=None, subnet=None, subnet_address_prefix=None, tags=None, terminate_notification_time=None, ultra_ssd_enabled=None, upgrade_policy_mode=None, use_unmanaged_disk=None, user_data=None, validate=None, vm_domain_name=None, vm_sku=None, vnet_address_prefix=None, vnet_name=None, zones=None):
    '''
    Create an Azure Virtual Machine Scale Set.
    '''
    return call_az("az vmss create", locals())


def deallocate(name, resource_group, instance_ids=None, no_wait=None):
    '''
    Deallocate VMs within a VMSS.
    '''
    return call_az("az vmss deallocate", locals())


def delete(name, resource_group, force_deletion=None, no_wait=None):
    return call_az("az vmss delete", locals())


def delete_instances(instance_ids, name, resource_group, no_wait=None):
    '''
    Delete VMs within a VMSS.
    '''
    return call_az("az vmss delete-instances", locals())


def get_instance_view(name, resource_group, instance_id=None):
    '''
    View an instance of a VMSS.
    '''
    return call_az("az vmss get-instance-view", locals())


def list(resource_group=None):
    '''
    List VMSS.
    '''
    return call_az("az vmss list", locals())


def list_instances(name, resource_group, expand=None, filter=None, select=None):
    '''
    Get a list of all virtual machines in a VM scale sets.
    '''
    return call_az("az vmss list-instances", locals())


def list_instance_connection_info(name, resource_group):
    '''
    Get the IP address and port number used to connect to individual VM instances within a set.
    '''
    return call_az("az vmss list-instance-connection-info", locals())


def list_instance_public_ips(name, resource_group):
    '''
    List public IP addresses of VM instances within a set.
    '''
    return call_az("az vmss list-instance-public-ips", locals())


def list_skus(name, resource_group):
    return call_az("az vmss list-skus", locals())


def reimage(name, resource_group, instance_id=None, no_wait=None):
    '''
    Reimage VMs within a VMSS.
    '''
    return call_az("az vmss reimage", locals())


def perform_maintenance(name, resource_group, vm_instance_i_ds=None):
    return call_az("az vmss perform-maintenance", locals())


def restart(name, resource_group, instance_ids=None, no_wait=None):
    '''
    Restart VMs within a VMSS.
    '''
    return call_az("az vmss restart", locals())


def scale(name, new_capacity, resource_group, no_wait=None):
    '''
    Change the number of VMs within a VMSS.
    '''
    return call_az("az vmss scale", locals())


def show(name, resource_group, include_user_data=None, instance_id=None):
    '''
    Get details on VMs within a VMSS.
    '''
    return call_az("az vmss show", locals())


def simulate_eviction(instance_id, name, resource_group):
    '''
    Simulate the eviction of a Spot virtual machine in a VM scale set.
    '''
    return call_az("az vmss simulate-eviction", locals())


def start(name, resource_group, instance_ids=None, no_wait=None):
    '''
    Start VMs within a VMSS.
    '''
    return call_az("az vmss start", locals())


def stop(name, resource_group, instance_ids=None, no_wait=None, skip_shutdown=None):
    '''
    Power off (stop) VMs within a VMSS.
    '''
    return call_az("az vmss stop", locals())


def update(name, resource_group, add=None, automatic_repairs_grace_period=None, capacity_reservation_group=None, enable_automatic_repairs=None, enable_cross_zone_upgrade=None, enable_spot_restore=None, enable_terminate_notification=None, ephemeral_os_disk_placement=None, force_string=None, instance_id=None, license_type=None, max_batch_instance_percent=None, max_price=None, max_unhealthy_instance_percent=None, max_unhealthy_upgraded_instance_percent=None, no_wait=None, pause_time_between_batches=None, ppg=None, prioritize_unhealthy_instances=None, priority=None, protect_from_scale_in=None, protect_from_scale_set_actions=None, remove=None, scale_in_policy=None, set=None, spot_restore_timeout=None, terminate_notification_time=None, ultra_ssd_enabled=None, user_data=None, vm_sku=None):
    '''
    Update a VMSS. Run 'az vmss update-instances' command to roll out the changes to VMs if you have not configured upgrade policy.
    '''
    return call_az("az vmss update", locals())


def update_instances(instance_ids, name, resource_group, no_wait=None):
    '''
    Upgrade VMs within a VMSS.
    '''
    return call_az("az vmss update-instances", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, instance_id=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a scale set is met.
    '''
    return call_az("az vmss wait", locals())


def get_os_upgrade_history(name, resource_group):
    return call_az("az vmss get-os-upgrade-history", locals())


def set_orchestration_service_state(action, name, resource_group, service_name, no_wait=None):
    '''
    Change ServiceState property for a given service within a VMSS.
    '''
    return call_az("az vmss set-orchestration-service-state", locals())




from ... pyaz_utils import call_az

def delete(name, resource_group, yes=None):
    '''
    Delete a network profile.
    '''
    return call_az("az network profile delete", locals())


def list(resource_group=None):
    '''
    List network profiles.
    '''
    return call_az("az network profile list", locals())


def show(name, resource_group, expand=None):
    '''
    Get the details of a network profile.
    '''
    return call_az("az network profile show", locals())




from .... pyaz_utils import call_az

def create(name, policy_name, resource_group, service, service_resources, description=None):
    '''
    Create a service endpoint policy definition.
    '''
    return call_az("az network service-endpoint policy-definition create", locals())


def delete(name, policy_name, resource_group):
    '''
    Delete a service endpoint policy definition.
    '''
    return call_az("az network service-endpoint policy-definition delete", locals())


def list(policy_name, resource_group):
    '''
    List service endpoint policy definitions.
    '''
    return call_az("az network service-endpoint policy-definition list", locals())


def show(name, policy_name, resource_group):
    '''
    Get the details of a service endpoint policy definition.
    '''
    return call_az("az network service-endpoint policy-definition show", locals())


def update(name, policy_name, resource_group, add=None, description=None, force_string=None, remove=None, service=None, service_resources=None, set=None):
    '''
    Update a service endpoint policy definition.
    '''
    return call_az("az network service-endpoint policy-definition update", locals())




from ... pyaz_utils import call_az

def init_recovery(sd_exchange_key, hsm_name=None, id=None):
    '''
    Retrieve the exchange key of the HSM.
    '''
    return call_az("az keyvault security-domain init-recovery", locals())


def upload(sd_exchange_key, sd_file, sd_wrapping_keys, hsm_name=None, id=None, no_wait=None, passwords=None):
    '''
    Start to restore the HSM.
    '''
    return call_az("az keyvault security-domain upload", locals())


def download(sd_quorum, sd_wrapping_keys, security_domain_file, hsm_name=None, id=None, no_wait=None):
    '''
    Download the security domain file from the HSM.
    '''
    return call_az("az keyvault security-domain download", locals())


def wait(hsm_name=None, id=None, target_operation=None):
    '''
    Place the CLI in a waiting state until HSM security domain operation is finished.
    '''
    return call_az("az keyvault security-domain wait", locals())




from .. pyaz_utils import call_az
from . import deployment, lock


def delete(name, force_deletion_types=None, no_wait=None, yes=None):
    '''
    Delete a resource group.
    '''
    return call_az("az group delete", locals())


def show(name):
    return call_az("az group show", locals())


def exists(name):
    '''
    Check if a resource group exists.
    '''
    return call_az("az group exists", locals())


def list(tag=None):
    '''
    List resource groups.
    '''
    return call_az("az group list", locals())


def create(location, name, managed_by=None, tags=None):
    '''
    Create a new resource group.
    '''
    return call_az("az group create", locals())


def export(name, include_comments=None, include_parameter_default_value=None, resource_ids=None, skip_all_params=None, skip_resource_name_params=None):
    return call_az("az group export", locals())


def update(name, add=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update a resource group.
    '''
    return call_az("az group update", locals())


def wait(name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the resource group is met.
    '''
    return call_az("az group wait", locals())




from .... pyaz_utils import call_az

def show(name, resource_group, scope_name):
    '''
    Show a private link resource of a private link scope resource.
    '''
    return call_az("az monitor private-link-scope private-link-resource show", locals())


def list(resource_group, scope_name):
    '''
    List all private link resources of a private link scope resource.
    '''
    return call_az("az monitor private-link-scope private-link-resource list", locals())




from ... pyaz_utils import call_az

def show(collection_name, db_name, key=None, name=None, resource_group_name=None, url_connection=None):
    return call_az("az cosmosdb collection show", locals())


def list(db_name, key=None, name=None, resource_group_name=None, url_connection=None):
    return call_az("az cosmosdb collection list", locals())


def exists(collection_name, db_name, key=None, name=None, resource_group_name=None, url_connection=None):
    return call_az("az cosmosdb collection exists", locals())


def create(collection_name, db_name, default_ttl=None, indexing_policy=None, key=None, name=None, partition_key_path=None, resource_group_name=None, throughput=None, url_connection=None):
    return call_az("az cosmosdb collection create", locals())


def delete(collection_name, db_name, key=None, name=None, resource_group_name=None, url_connection=None, yes=None):
    return call_az("az cosmosdb collection delete", locals())


def update(collection_name, db_name, default_ttl=None, indexing_policy=None, key=None, name=None, resource_group_name=None, throughput=None, url_connection=None):
    return call_az("az cosmosdb collection update", locals())




from .... pyaz_utils import call_az

def create(account, id_provider, trusted_id_provider_name, resource_group=None):
    return call_az("az dls account trusted-provider create", locals())


def update(account, trusted_id_provider_name, id_provider=None, resource_group=None):
    return call_az("az dls account trusted-provider update", locals())


def list(account, resource_group=None):
    return call_az("az dls account trusted-provider list", locals())


def show(account, trusted_id_provider_name, resource_group=None):
    return call_az("az dls account trusted-provider show", locals())


def delete(account, trusted_id_provider_name, resource_group=None):
    return call_az("az dls account trusted-provider delete", locals())




from ... pyaz_utils import call_az

def list(assessed_resource_id=None, assessment_name=None):
    '''
    List all security sub assessment results.
    '''
    return call_az("az security sub-assessment list", locals())


def show(assessment_name, name, assessed_resource_id=None):
    '''
    Shows a security sub assessment.
    '''
    return call_az("az security sub-assessment show", locals())




from ... pyaz_utils import call_az

def list():
    '''
    List security contact.
    '''
    return call_az("az security contact list", locals())


def show(name):
    '''
    Shows a security contact.
    '''
    return call_az("az security contact show", locals())


def create(email, name, alert_notifications=None, alerts_admins=None, phone=None):
    '''
    Creates a security contact.
    '''
    return call_az("az security contact create", locals())


def delete(name):
    '''
    Deletes a security contact.
    '''
    return call_az("az security contact delete", locals())




from .... pyaz_utils import call_az

def start(destination_blob, destination_container, account_key=None, account_name=None, auth_mode=None, connection_string=None, destination_if_match=None, destination_if_modified_since=None, destination_if_none_match=None, destination_if_unmodified_since=None, destination_lease_id=None, metadata=None, sas_token=None, source_account_key=None, source_account_name=None, source_blob=None, source_container=None, source_lease_id=None, source_sas=None, source_snapshot=None, source_uri=None, timeout=None):
    '''
    Copies an incremental copy of a blob asynchronously.
    '''
    return call_az("az storage blob incremental-copy start", locals())


def cancel(container_name, copy_id, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, lease_id=None, sas_token=None, timeout=None):
    return call_az("az storage blob incremental-copy cancel", locals())




from .... pyaz_utils import call_az

def set(account_name, container_name, tags, allow_protected_append_writes_all=None, resource_group=None):
    '''
    Set legal hold tags.
    '''
    return call_az("az storage container legal-hold set", locals())


def clear(account_name, container_name, tags, allow_protected_append_writes_all=None, resource_group=None):
    '''
    Clear legal hold tags.
    '''
    return call_az("az storage container legal-hold clear", locals())


def show(account_name, container_name, resource_group=None):
    '''
    Get the legal hold properties of a container.
    '''
    return call_az("az storage container legal-hold show", locals())




from ... pyaz_utils import call_az
from . import group


def update(name, resource_group, add=None, backup_pwd=None, backup_schedule_type=None, backup_system_dbs=None, connectivity_type=None, credential_name=None, day_of_week=None, enable_auto_backup=None, enable_auto_patching=None, enable_encryption=None, enable_key_vault_credential=None, enable_r_services=None, force_string=None, full_backup_duration=None, full_backup_frequency=None, full_backup_start_hour=None, image_sku=None, key_vault=None, license_type=None, log_backup_frequency=None, maintenance_window_duration=None, maintenance_window_start_hour=None, port=None, remove=None, retention_period=None, sa_key=None, set=None, sp_name=None, sp_secret=None, sql_mgmt_type=None, sql_workload_type=None, storage_account=None, tags=None, yes=None):
    '''
    Updates the properties of a SQL virtual machine.
    '''
    return call_az("az sql vm update", locals())


def show(name, resource_group, expand=None):
    return call_az("az sql vm show", locals())


def list(resource_group=None):
    return call_az("az sql vm list", locals())


def add_to_group(name, resource_group, sqlvm_group, operator_acc_pwd=None, service_acc_pwd=None):
    '''
    Adds SQL virtual machine to a SQL virtual machine group.
    '''
    return call_az("az sql vm add-to-group", locals())


def remove_from_group(name, resource_group):
    '''
    Remove SQL virtual machine from its current SQL virtual machine group.
    '''
    return call_az("az sql vm remove-from-group", locals())


def delete(name, resource_group, yes=None):
    return call_az("az sql vm delete", locals())


def create(name, resource_group, backup_pwd=None, backup_schedule_type=None, backup_system_dbs=None, connectivity_type=None, credential_name=None, day_of_week=None, enable_auto_backup=None, enable_auto_patching=None, enable_encryption=None, enable_key_vault_credential=None, enable_r_services=None, full_backup_duration=None, full_backup_frequency=None, full_backup_start_hour=None, image_offer=None, image_sku=None, key_vault=None, license_type=None, location=None, log_backup_frequency=None, maintenance_window_duration=None, maintenance_window_start_hour=None, port=None, retention_period=None, sa_key=None, sp_name=None, sp_secret=None, sql_auth_update_pwd=None, sql_auth_update_username=None, sql_mgmt_type=None, sql_workload_type=None, storage_account=None, tags=None):
    '''
    Creates a SQL virtual machine.
    '''
    return call_az("az sql vm create", locals())




from ... pyaz_utils import call_az

def show(name, resource_group, with_secrets=None):
    '''
    Get details of the Webchat Channel on a bot
    '''
    return call_az("az bot webchat show", locals())




from .... pyaz_utils import call_az
from . import action, condition


def show(name, profile_name, resource_group):
    '''
    Show delivery rules asscociate with the endpoint.
    '''
    return call_az("az cdn endpoint rule show", locals())


def add(action_name, name, order, profile_name, resource_group, cache_behavior=None, cache_duration=None, custom_fragment=None, custom_hostname=None, custom_path=None, custom_querystring=None, destination=None, header_action=None, header_name=None, header_value=None, match_values=None, match_variable=None, negate_condition=None, operator=None, origin_group=None, preserve_unmatched_path=None, query_parameters=None, query_string_behavior=None, redirect_protocol=None, redirect_type=None, rule_name=None, selector=None, source_pattern=None, transform=None):
    '''
    Add a delivery rule to a CDN endpoint.
    '''
    return call_az("az cdn endpoint rule add", locals())


def remove(name, profile_name, resource_group, order=None, rule_name=None):
    '''
    Remove a delivery rule from an endpoint.
    '''
    return call_az("az cdn endpoint rule remove", locals())




from ... pyaz_utils import call_az
from . import file, node


def create(cluster, config_file, experiment, name, resource_group, workspace, afs_mount_path=None, afs_name=None, bfs_mount_path=None, bfs_name=None, nfs=None, nfs_mount_path=None, storage_account_key=None, storage_account_name=None):
    '''
    Create a job.
    '''
    return call_az("az batchai job create", locals())


def delete(experiment, name, resource_group, workspace, no_wait=None, yes=None):
    '''
    Delete a job.
    '''
    return call_az("az batchai job delete", locals())


def terminate(experiment, name, resource_group, workspace, no_wait=None, yes=None):
    '''
    Terminate a job.
    '''
    return call_az("az batchai job terminate", locals())


def show(experiment, name, resource_group, workspace):
    '''
    Show information about a job.
    '''
    return call_az("az batchai job show", locals())


def list(experiment, resource_group, workspace):
    '''
    List jobs.
    '''
    return call_az("az batchai job list", locals())


def wait(experiment, name, resource_group, workspace, interval=None):
    '''
    Waits for specified job completion and setups the exit code to the job's exit code.
    '''
    return call_az("az batchai job wait", locals())




from .. pyaz_utils import call_az
from . import backup, certificate, key, network_rule, private_endpoint_connection, private_link_resource, restore, secret, security_domain, storage


def create(resource_group, administrators=None, bypass=None, default_action=None, enable_purge_protection=None, enable_rbac_authorization=None, enable_soft_delete=None, enabled_for_deployment=None, enabled_for_disk_encryption=None, enabled_for_template_deployment=None, hsm_name=None, location=None, name=None, network_acls=None, network_acls_ips=None, network_acls_vnets=None, no_self_perms=None, no_wait=None, public_network_access=None, retention_days=None, sku=None, tags=None):
    '''
    Create a Vault or HSM.
    '''
    return call_az("az keyvault create", locals())


def recover(hsm_name=None, location=None, name=None, no_wait=None, resource_group=None):
    '''
    Recover a Vault or HSM.
    '''
    return call_az("az keyvault recover", locals())


def list(resource_group=None, resource_type=None):
    '''
    List Vaults and/or HSMs.
    '''
    return call_az("az keyvault list", locals())


def show(hsm_name=None, name=None, resource_group=None):
    '''
    Show details of a Vault or HSM.
    '''
    return call_az("az keyvault show", locals())


def delete(hsm_name=None, name=None, no_wait=None, resource_group=None):
    '''
    Delete a Vault or HSM.
    '''
    return call_az("az keyvault delete", locals())


def purge(hsm_name=None, location=None, name=None, no_wait=None):
    '''
    Permanently delete the specified Vault or HSM. Aka Purges the deleted Vault or HSM.
    '''
    return call_az("az keyvault purge", locals())


def set_policy(name, application_id=None, certificate_permissions=None, key_permissions=None, no_wait=None, object_id=None, resource_group=None, secret_permissions=None, spn=None, storage_permissions=None, upn=None):
    '''
    Update security policy settings for a Key Vault.
    '''
    return call_az("az keyvault set-policy", locals())


def delete_policy(name, application_id=None, no_wait=None, object_id=None, resource_group=None, spn=None, upn=None):
    return call_az("az keyvault delete-policy", locals())


def list_deleted(resource_type=None):
    '''
    Get information about the deleted Vaults or HSMs in a subscription.
    '''
    return call_az("az keyvault list-deleted", locals())


def show_deleted(hsm_name=None, location=None, name=None):
    '''
    Show details of a deleted Vault or HSM.
    '''
    return call_az("az keyvault show-deleted", locals())


def update(name, add=None, bypass=None, default_action=None, enable_purge_protection=None, enable_rbac_authorization=None, enable_soft_delete=None, enabled_for_deployment=None, enabled_for_disk_encryption=None, enabled_for_template_deployment=None, force_string=None, no_wait=None, public_network_access=None, remove=None, resource_group=None, retention_days=None, set=None):
    '''
    Update the properties of a Vault.
    '''
    return call_az("az keyvault update", locals())


def wait(name, created=None, custom=None, deleted=None, exists=None, interval=None, resource_group=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the Vault is met.
    '''
    return call_az("az keyvault wait", locals())


def update_hsm(hsm_name, add=None, bypass=None, default_action=None, enable_purge_protection=None, force_string=None, no_wait=None, remove=None, resource_group=None, secondary_locations=None, set=None):
    '''
    Update the properties of a HSM.
    '''
    return call_az("az keyvault update-hsm", locals())


def wait_hsm(hsm_name, created=None, custom=None, deleted=None, exists=None, interval=None, resource_group=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the HSM is met.
    '''
    return call_az("az keyvault wait-hsm", locals())




from .... pyaz_utils import call_az

def list(name, resource_group, slot=None):
    '''
    List all continuous webjobs on a selected web app.
    '''
    return call_az("az webapp webjob continuous list", locals())


def remove(name, resource_group, webjob_name, slot=None):
    '''
    Delete a specific continuous webjob.
    '''
    return call_az("az webapp webjob continuous remove", locals())


def start(name, resource_group, webjob_name, slot=None):
    '''
    Start a specific continuous webjob on a selected web app.
    '''
    return call_az("az webapp webjob continuous start", locals())


def stop(name, resource_group, webjob_name, slot=None):
    '''
    Stop a specific continuous webjob.
    '''
    return call_az("az webapp webjob continuous stop", locals())




from ... pyaz_utils import call_az

def create(file, name, workspace_name, no_wait=None):
    '''
    Create a data flow.
    '''
    return call_az("az synapse data-flow create", locals())


def set(file, name, workspace_name, no_wait=None):
    '''
    Set an exist data flow.
    '''
    return call_az("az synapse data-flow set", locals())


def list(workspace_name):
    '''
    List data flows.
    '''
    return call_az("az synapse data-flow list", locals())


def show(name, workspace_name):
    '''
    Get a data flow.
    '''
    return call_az("az synapse data-flow show", locals())


def delete(name, workspace_name, no_wait=None, yes=None):
    '''
    Delete a data flow.
    '''
    return call_az("az synapse data-flow delete", locals())




from .... pyaz_utils import call_az

def add(name, registry, schedule, timer_name, enabled=None, resource_group=None):
    '''
    Add a timer trigger to a task.
    '''
    return call_az("az acr task timer add", locals())


def update(name, registry, timer_name, enabled=None, resource_group=None, schedule=None):
    '''
    Update the timer trigger for a task.
    '''
    return call_az("az acr task timer update", locals())


def remove(name, registry, timer_name, resource_group=None):
    '''
    Remove a timer trigger from a task.
    '''
    return call_az("az acr task timer remove", locals())


def list(name, registry, resource_group=None):
    '''
    List all timer triggers for a task.
    '''
    return call_az("az acr task timer list", locals())




from ... pyaz_utils import call_az

def show(endpoint_name, name, profile_name, resource_group):
    return call_az("az cdn origin show", locals())


def list(endpoint_name, profile_name, resource_group):
    return call_az("az cdn origin list", locals())


def create(endpoint_name, host_name, name, profile_name, resource_group, disabled=None, http_port=None, https_port=None, origin_host_header=None, priority=None, private_link_approval_message=None, private_link_location=None, private_link_resource_id=None, weight=None):
    '''
    Create an origin.
    '''
    return call_az("az cdn origin create", locals())


def update(endpoint_name, name, profile_name, resource_group, disabled=None, host_name=None, http_port=None, https_port=None, origin_host_header=None, priority=None, private_link_approval_message=None, private_link_location=None, private_link_resource_id=None, weight=None):
    '''
    Update an origin.
    '''
    return call_az("az cdn origin update", locals())


def delete(endpoint_name, name, profile_name, resource_group, yes=None):
    return call_az("az cdn origin delete", locals())




from .... pyaz_utils import call_az

def list(job_id, account_endpoint=None, account_key=None, account_name=None, filter=None, select=None):
    return call_az("az batch job prep-release-status list", locals())




from ... pyaz_utils import call_az
from . import akamai


def list(account_name, resource_group):
    '''
    List all the streaming endpoints within an Azure Media Services account.
    '''
    return call_az("az ams streaming-endpoint list", locals())


def start(account_name, name, resource_group, no_wait=None):
    '''
    Start a streaming endpoint.
    '''
    return call_az("az ams streaming-endpoint start", locals())


def stop(account_name, name, resource_group, no_wait=None):
    '''
    Stop a streaming endpoint.
    '''
    return call_az("az ams streaming-endpoint stop", locals())


def create(account_name, name, resource_group, scale_units, auto_start=None, availability_set_name=None, cdn_profile=None, cdn_provider=None, client_access_policy=None, cross_domain_policy=None, custom_host_names=None, description=None, ips=None, max_cache_age=None, no_wait=None, tags=None):
    '''
    Create a streaming endpoint.
    '''
    return call_az("az ams streaming-endpoint create", locals())


def scale(account_name, name, resource_group, scale_units):
    '''
    Set the scale of a streaming endpoint.
    '''
    return call_az("az ams streaming-endpoint scale", locals())


def update(account_name, name, resource_group, add=None, cdn_profile=None, cdn_provider=None, client_access_policy=None, cross_domain_policy=None, custom_host_names=None, description=None, disable_cdn=None, force_string=None, ips=None, max_cache_age=None, no_wait=None, remove=None, set=None, tags=None):
    '''
    Update the details of a streaming endpoint.
    '''
    return call_az("az ams streaming-endpoint update", locals())


def show(account_name, name, resource_group):
    '''
    Show the details of a streaming endpoint.
    '''
    return call_az("az ams streaming-endpoint show", locals())


def delete(account_name, name, resource_group):
    '''
    Delete a streaming endpoint.
    '''
    return call_az("az ams streaming-endpoint delete", locals())


def wait(account_name, name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the streaming endpoint is met.
    '''
    return call_az("az ams streaming-endpoint wait", locals())




from ... pyaz_utils import call_az
from . import client_certificate, durability, node, node_type, reliability, setting, upgrade_type


def show(cluster_name, resource_group):
    return call_az("az sf cluster show", locals())


def list(resource_group=None):
    '''
    List cluster resources.
    '''
    return call_az("az sf cluster list", locals())


def create(resource_group, certificate_file=None, certificate_output_folder=None, certificate_password=None, certificate_subject_name=None, cluster_name=None, cluster_size=None, location=None, parameter_file=None, secret_identifier=None, template_file=None, vault_name=None, vault_rg=None, vm_os=None, vm_password=None, vm_sku=None, vm_user_name=None):
    '''
    Create a new Azure Service Fabric cluster.
    '''
    return call_az("az sf cluster create", locals())




from .... pyaz_utils import call_az

def create(gateway_name, name, resource_group, thumbprint):
    '''
    Revoke a certificate.
    '''
    return call_az("az network vnet-gateway revoked-cert create", locals())


def delete(gateway_name, name, resource_group):
    '''
    Delete a revoked certificate.
    '''
    return call_az("az network vnet-gateway revoked-cert delete", locals())




from .... pyaz_utils import call_az

def create(name, peer_asn, peer_ip, resource_group, routeserver, no_wait=None):
    '''
    Create a route server peering.
    '''
    return call_az("az network routeserver peering create", locals())


def update(name, resource_group, routeserver, add=None, force_string=None, peer_asn=None, peer_ip=None, remove=None, set=None):
    '''
    Update a route server peering.
    '''
    return call_az("az network routeserver peering update", locals())


def delete(name, resource_group, routeserver, no_wait=None, yes=None):
    '''
    Delete a route server peering.
    '''
    return call_az("az network routeserver peering delete", locals())


def show(name, resource_group, routeserver):
    '''
    Show a route server peering
    '''
    return call_az("az network routeserver peering show", locals())


def wait(name, resource_group, routeserver, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the route server peering is met.
    '''
    return call_az("az network routeserver peering wait", locals())


def list(resource_group, routeserver):
    '''
    List all route server peerings under a resource group.
    '''
    return call_az("az network routeserver peering list", locals())


def list_learned_routes(name, resource_group, routeserver):
    '''
    List all routes the route server bgp connection has learned.
    '''
    return call_az("az network routeserver peering list-learned-routes", locals())


def list_advertised_routes(name, resource_group, routeserver):
    '''
    List all routes the route server bgp connection is advertising to the specified peer.
    '''
    return call_az("az network routeserver peering list-advertised-routes", locals())




from .... pyaz_utils import call_az
from . import rule


def list(gateway_name, resource_group):
    '''
    List URL path maps.
    '''
    return call_az("az network application-gateway url-path-map list", locals())


def show(gateway_name, name, resource_group):
    '''
    Get the details of a URL path map.
    '''
    return call_az("az network application-gateway url-path-map show", locals())


def delete(gateway_name, name, resource_group, no_wait=None):
    '''
    Delete a URL path map.
    '''
    return call_az("az network application-gateway url-path-map delete", locals())


def create(gateway_name, name, paths, resource_group, address_pool=None, default_address_pool=None, default_http_settings=None, default_redirect_config=None, default_rewrite_rule_set=None, http_settings=None, no_wait=None, redirect_config=None, rewrite_rule_set=None, rule_name=None, waf_policy=None):
    '''
    Create a URL path map.
    '''
    return call_az("az network application-gateway url-path-map create", locals())


def update(gateway_name, name, resource_group, add=None, default_address_pool=None, default_http_settings=None, default_redirect_config=None, default_rewrite_rule_set=None, force_string=None, no_wait=None, remove=None, set=None):
    '''
    Update a URL path map.
    '''
    return call_az("az network application-gateway url-path-map update", locals())




from ..... pyaz_utils import call_az

def list(gateway_name, resource_group):
    '''
    List rewrite rule sets.
    '''
    return call_az("az network application-gateway rewrite-rule set list", locals())


def show(gateway_name, name, resource_group):
    '''
    Get the details of a rewrite rule set.
    '''
    return call_az("az network application-gateway rewrite-rule set show", locals())


def delete(gateway_name, name, resource_group, no_wait=None):
    '''
    Delete a rewrite rule set.
    '''
    return call_az("az network application-gateway rewrite-rule set delete", locals())


def create(gateway_name, name, resource_group, no_wait=None):
    '''
    Create a rewrite rule set.
    '''
    return call_az("az network application-gateway rewrite-rule set create", locals())


def update(gateway_name, name, resource_group, add=None, force_string=None, no_wait=None, remove=None, set=None):
    '''
    Update a rewrite rule set.
    '''
    return call_az("az network application-gateway rewrite-rule set update", locals())




from ... pyaz_utils import call_az

def list():
    '''
    Shows the Azure Defender plans for the subscription.
    '''
    return call_az("az security pricing list", locals())


def show(name):
    '''
    Shows the Azure Defender plan for the subscription
    '''
    return call_az("az security pricing show", locals())


def create(name, tier):
    '''
    Updates the Azure defender plan for the subscription.
    '''
    return call_az("az security pricing create", locals())




from .... pyaz_utils import call_az

def create(executor_size, executors, name, spark_pool_name, workspace_name, configuration=None, reference_files=None, tags=None):
    '''
    Create a Spark session.
    '''
    return call_az("az synapse spark session create", locals())


def list(spark_pool_name, workspace_name, from_index=None, size=None):
    '''
    List all Spark sessions.
    '''
    return call_az("az synapse spark session list", locals())


def show(livy_id, spark_pool_name, workspace_name):
    '''
    Get a Spark session.
    '''
    return call_az("az synapse spark session show", locals())


def cancel(livy_id, spark_pool_name, workspace_name, yes=None):
    '''
    Cancel a Spark session.
    '''
    return call_az("az synapse spark session cancel", locals())


def reset_timeout(livy_id, spark_pool_name, workspace_name):
    '''
    Reset a Spark session timeout time.
    '''
    return call_az("az synapse spark session reset-timeout", locals())




from ... pyaz_utils import call_az
from . import option


def create(account_name, name, policy_option_name, resource_group, alt_rsa_token_keys=None, alt_symmetric_token_keys=None, alt_x509_token_keys=None, ask=None, audience=None, clear_key_configuration=None, description=None, fair_play_pfx=None, fair_play_pfx_password=None, fp_playback_duration_seconds=None, fp_storage_duration_seconds=None, issuer=None, open_id_connect_discovery_document=None, open_restriction=None, play_ready_template=None, rental_and_lease_key_type=None, rental_duration=None, token_claims=None, token_key=None, token_key_type=None, token_type=None, widevine_template=None):
    '''
    Create a new content key policy.
    '''
    return call_az("az ams content-key-policy create", locals())


def show(account_name, name, resource_group, with_secrets=None):
    '''
    Show an existing content key policy.
    '''
    return call_az("az ams content-key-policy show", locals())


def delete(account_name, name, resource_group):
    '''
    Delete a content key policy.
    '''
    return call_az("az ams content-key-policy delete", locals())


def list(account_name, resource_group, filter=None, orderby=None, top=None):
    '''
    List all the content key policies within an Azure Media Services account.
    '''
    return call_az("az ams content-key-policy list", locals())


def update(account_name, name, resource_group, add=None, description=None, force_string=None, remove=None, set=None):
    '''
    Update an existing content key policy.
    '''
    return call_az("az ams content-key-policy update", locals())




from ... pyaz_utils import call_az
from . import authorization_rule


def create(name, namespace_name, relay_type, resource_group, requires_client_authorization=None, requires_transport_security=None, user_metadata=None):
    '''
    Create the Relay Service WCF Relay
    '''
    return call_az("az relay wcfrelay create", locals())


def show(name, namespace_name, resource_group):
    '''
    shows the Relay Service WCF Relay Details
    '''
    return call_az("az relay wcfrelay show", locals())


def list(namespace_name, resource_group):
    '''
    List the WCF Relay by Relay Service Namespace
    '''
    return call_az("az relay wcfrelay list", locals())


def delete(name, namespace_name, resource_group):
    '''
    Deletes the Relay Service WCF Relay
    '''
    return call_az("az relay wcfrelay delete", locals())


def update(name, namespace_name, resource_group, add=None, force_string=None, relay_type=None, remove=None, set=None, status=None, user_metadata=None):
    '''
    Updates existing Relay Service WCF Relay
    '''
    return call_az("az relay wcfrelay update", locals())




from ... pyaz_utils import call_az

def list(id=None, include_managed=None, maxresults=None, vault_name=None):
    return call_az("az keyvault secret list", locals())


def list_versions(id=None, maxresults=None, name=None, vault_name=None):
    return call_az("az keyvault secret list-versions", locals())


def list_deleted(vault_name, id=None, maxresults=None):
    return call_az("az keyvault secret list-deleted", locals())


def set(name, vault_name, description=None, disabled=None, encoding=None, expires=None, file=None, not_before=None, secret_attributes=None, tags=None, value=None):
    '''
    Create a secret (if one doesn't exist) or update a secret in a KeyVault.
    '''
    return call_az("az keyvault secret set", locals())


def set_attributes(content_type=None, enabled=None, expires=None, id=None, name=None, not_before=None, secret_attributes=None, tags=None, vault_name=None, version=None):
    return call_az("az keyvault secret set-attributes", locals())


def show(id=None, name=None, vault_name=None, version=None):
    return call_az("az keyvault secret show", locals())


def show_deleted(id=None, name=None, vault_name=None):
    return call_az("az keyvault secret show-deleted", locals())


def delete(id=None, name=None, vault_name=None):
    return call_az("az keyvault secret delete", locals())


def purge(id=None, name=None, vault_name=None):
    return call_az("az keyvault secret purge", locals())


def recover(id=None, name=None, vault_name=None):
    return call_az("az keyvault secret recover", locals())


def download(file, encoding=None, id=None, name=None, vault_name=None, version=None):
    return call_az("az keyvault secret download", locals())


def backup(file, id=None, name=None, vault_name=None):
    return call_az("az keyvault secret backup", locals())


def restore(file, vault_name):
    return call_az("az keyvault secret restore", locals())




from ... pyaz_utils import call_az

def create(display_name, named_value_id, resource_group, service_name, secret=None, tags=None, value=None):
    '''
    Create an API Management Named Value.
    '''
    return call_az("az apim nv create", locals())


def show(named_value_id, resource_group, service_name):
    '''
    Show details of an API Management Named Value.
    '''
    return call_az("az apim nv show", locals())


def list(resource_group, service_name):
    '''
    List API Management Named Values.
    '''
    return call_az("az apim nv list", locals())


def delete(named_value_id, resource_group, service_name, yes=None):
    '''
    Delete an API Management Named Value.
    '''
    return call_az("az apim nv delete", locals())


def show_secret(named_value_id, resource_group, service_name):
    '''
    Gets the secret of an API Management Named Value.
    '''
    return call_az("az apim nv show-secret", locals())


def update(named_value_id, resource_group, service_name, add=None, force_string=None, if_match=None, remove=None, secret=None, set=None, tags=None, value=None):
    '''
    Update an API Management Named Value.
    '''
    return call_az("az apim nv update", locals())




from .... pyaz_utils import call_az
from . import ip_config


def add(frontend_ip, gateway_name, name, resource_group, subnet, ip_address=None, no_wait=None, primary=None, subnet_prefix=None):
    '''
    Add a new Private Link with a default IP Configuration and associate it with an existing Frontend IP
    '''
    return call_az("az network application-gateway private-link add", locals())


def remove(gateway_name, name, resource_group, no_wait=None, yes=None):
    '''
    Remove a Private Link and clear association with Frontend IP. The subnet associate with a Private Link might need to clear manually
    '''
    return call_az("az network application-gateway private-link remove", locals())


def show(gateway_name, name, resource_group):
    '''
    Show a Private Link
    '''
    return call_az("az network application-gateway private-link show", locals())


def list(gateway_name, resource_group):
    '''
    List all the Private Link
    '''
    return call_az("az network application-gateway private-link list", locals())


def wait(gateway_name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until the condition of corresponding application gateway is met
    '''
    return call_az("az network application-gateway private-link wait", locals())




from ... pyaz_utils import call_az

def list(name, resource_group=None):
    '''
    List network rules.
    '''
    return call_az("az acr network-rule list", locals())


def add(name, ip_address=None, resource_group=None, subnet=None, vnet_name=None):
    '''
    Add a network rule.
    '''
    return call_az("az acr network-rule add", locals())


def remove(name, ip_address=None, resource_group=None, subnet=None, vnet_name=None):
    '''
    Remove a network rule.
    '''
    return call_az("az acr network-rule remove", locals())




from ... pyaz_utils import call_az
from . import pipeline, recurrence


def submit(account, job_name, script, compile_mode=None, compile_only=None, degree_of_parallelism=None, pipeline_id=None, pipeline_name=None, pipeline_uri=None, priority=None, recurrence_id=None, recurrence_name=None, run_id=None, runtime_version=None):
    '''
    Submit a job to a Data Lake Analytics account.
    '''
    return call_az("az dla job submit", locals())


def wait(account, job_id, max_wait_time_sec=None, wait_interval_sec=None):
    '''
    Wait for a Data Lake Analytics job to finish.
    '''
    return call_az("az dla job wait", locals())


def show(account, job_identity):
    '''
    Get information for a Data Lake Analytics job.
    '''
    return call_az("az dla job show", locals())


def cancel(account, job_identity):
    '''
    Cancel a Data Lake Analytics job.
    '''
    return call_az("az dla job cancel", locals())


def list(account, name=None, pipeline_id=None, recurrence_id=None, result=None, state=None, submitted_after=None, submitted_before=None, submitter=None, top=None):
    '''
    List Data Lake Analytics jobs.
    '''
    return call_az("az dla job list", locals())




from .... pyaz_utils import call_az
from . import throughput


def create(account_name, name, resource_group, max_throughput=None, throughput=None):
    '''
    Create an Gremlin database under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb gremlin database create", locals())


def exists(account_name, name, resource_group):
    return call_az("az cosmosdb gremlin database exists", locals())


def list(account_name, resource_group):
    '''
    List the Gremlin databases under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb gremlin database list", locals())


def show(account_name, name, resource_group):
    '''
    Show the details of a Gremlin database under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb gremlin database show", locals())


def delete(account_name, name, resource_group, yes=None):
    '''
    Delete the Gremlin database under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb gremlin database delete", locals())




from .... pyaz_utils import call_az

def create(gateway_name, name, public_cert_data, resource_group):
    '''
    Upload a root certificate.
    '''
    return call_az("az network vnet-gateway root-cert create", locals())


def delete(gateway_name, name, resource_group):
    '''
    Delete a root certificate.
    '''
    return call_az("az network vnet-gateway root-cert delete", locals())




from .. pyaz_utils import call_az

def show(plan, product, publisher):
    '''
    Get marketplace terms.
    '''
    return call_az("az term show", locals())


def accept(plan, product, publisher):
    '''
    Accept marketplace terms.
    '''
    return call_az("az term accept", locals())




from .... pyaz_utils import call_az
from . import address, tunnel_interface


def create(lb_name, name, resource_group, backend_address=None, backend_addresses_config_file=None, vnet=None):
    '''
    Create an address pool.
    '''
    return call_az("az network lb address-pool create", locals())


def update(lb_name, name, resource_group, add=None, backend_address=None, backend_addresses_config_file=None, force_string=None, remove=None, set=None, vnet=None):
    '''
    Update an address pool.
    '''
    return call_az("az network lb address-pool update", locals())


def show(lb_name, name, resource_group):
    '''
    Get the details of an address pool.
    '''
    return call_az("az network lb address-pool show", locals())


def list(lb_name, resource_group):
    '''
    List address pools.
    '''
    return call_az("az network lb address-pool list", locals())


def delete(lb_name, name, resource_group):
    '''
    Delete an address pool.
    '''
    return call_az("az network lb address-pool delete", locals())




from ... pyaz_utils import call_az

def list(name, resource_group):
    '''
    Show all OAuth connection settings on a bot.
    '''
    return call_az("az bot authsetting list", locals())


def show(name, resource_group, setting_name):
    '''
    Show details of an OAuth connection setting on a bot.
    '''
    return call_az("az bot authsetting show", locals())


def delete(name, resource_group, setting_name):
    '''
    Delete an OAuth connection setting on a bot.
    '''
    return call_az("az bot authsetting delete", locals())


def create(client_id, client_secret, name, provider_scope_string, resource_group, service, setting_name, parameters=None):
    '''
    Create an OAuth connection setting on a bot.
    '''
    return call_az("az bot authsetting create", locals())


def list_providers(provider_name=None):
    '''
    List details for all service providers available for creating OAuth connection settings.
    '''
    return call_az("az bot authsetting list-providers", locals())




from ... pyaz_utils import call_az

def list(workspace_name):
    '''
    List SQL scripts in a synapse workspace.
    '''
    return call_az("az synapse sql-script list", locals())


def show(name, workspace_name):
    '''
    Get a SQL script.
    '''
    return call_az("az synapse sql-script show", locals())


def delete(name, workspace_name, no_wait=None):
    '''
    Delete a SQL script.
    '''
    return call_az("az synapse sql-script delete", locals())


def create(file, name, workspace_name, additional_properties=None, description=None, folder_name=None, no_wait=None, result_limit=None, sql_database_name=None, sql_pool_name=None):
    '''
    Create or update a SQL script.
    '''
    return call_az("az synapse sql-script create", locals())


def wait(name, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a sql script is met.
    '''
    return call_az("az synapse sql-script wait", locals())


def export(output_folder, workspace_name, name=None):
    '''
    Export a SQL script.
    '''
    return call_az("az synapse sql-script export", locals())


def import_(file, name, workspace_name, additional_properties=None, description=None, folder_name=None, no_wait=None, result_limit=None, sql_database_name=None, sql_pool_name=None):
    '''
    Import a SQL script.
    '''
    return call_az("az synapse sql-script import", locals())




from .... pyaz_utils import call_az
from . import throughput


def create(account_name, name, resource_group, max_throughput=None, throughput=None):
    '''
    Create an MongoDB database under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb mongodb database create", locals())


def exists(account_name, name, resource_group):
    return call_az("az cosmosdb mongodb database exists", locals())


def list(account_name, resource_group):
    '''
    List the MongoDB databases under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb mongodb database list", locals())


def show(account_name, name, resource_group):
    '''
    Show the details of a MongoDB database under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb mongodb database show", locals())


def delete(account_name, name, resource_group, yes=None):
    '''
    Delete the MongoDB database under an Azure Cosmos DB account.
    '''
    return call_az("az cosmosdb mongodb database delete", locals())




from ... pyaz_utils import call_az

def list(control_name, standard_name):
    '''
    Get details and state of assessments mapped to selected regulatory compliance control.
    '''
    return call_az("az security regulatory-compliance-assessments list", locals())


def show(control_name, name, standard_name):
    '''
    Shows supported regulatory compliance details and state for selected assessment.
    '''
    return call_az("az security regulatory-compliance-assessments show", locals())




from ... pyaz_utils import call_az

def list(resource_group, service_name):
    return call_az("az search private-endpoint-connection list", locals())


def show(private_endpoint_connection_name, resource_group, service_name):
    return call_az("az search private-endpoint-connection show", locals())


def delete(private_endpoint_connection_name, resource_group, service_name, yes=None):
    return call_az("az search private-endpoint-connection delete", locals())


def update(actions_required, description, name, resource_group, service_name, status):
    return call_az("az search private-endpoint-connection update", locals())




from ... pyaz_utils import call_az
from . import sas_definition


def add(active_key_name, name, resource_id, vault_name, auto_regenerate_key=None, disabled=None, regeneration_period=None, tags=None):
    return call_az("az keyvault storage add", locals())


def list(vault_name, maxresults=None):
    return call_az("az keyvault storage list", locals())


def show(id=None, name=None, vault_name=None):
    return call_az("az keyvault storage show", locals())


def update(active_key_name=None, auto_regenerate_key=None, disabled=None, id=None, name=None, regeneration_period=None, tags=None, vault_name=None):
    return call_az("az keyvault storage update", locals())


def remove(id=None, name=None, vault_name=None):
    '''
    Remove a Key Vault managed Azure Storage Account and all associated SAS definitions. This operation requires the storage/delete permission.
    '''
    return call_az("az keyvault storage remove", locals())


def regenerate_key(key_name, id=None, name=None, vault_name=None):
    return call_az("az keyvault storage regenerate-key", locals())


def list_deleted(vault_name, maxresults=None):
    return call_az("az keyvault storage list-deleted", locals())


def show_deleted(name, vault_name):
    return call_az("az keyvault storage show-deleted", locals())


def purge(name, vault_name):
    return call_az("az keyvault storage purge", locals())


def recover(name, vault_name):
    return call_az("az keyvault storage recover", locals())


def backup(file, id=None, name=None, vault_name=None):
    return call_az("az keyvault storage backup", locals())


def restore(file, vault_name):
    return call_az("az keyvault storage restore", locals())




from ... pyaz_utils import call_az

def list(resource_group=None):
    '''
    List all IoT Security solutions.
    '''
    return call_az("az security iot-solution list", locals())


def show(resource_group, solution_name):
    '''
    Shows a IoT Security solution.
    '''
    return call_az("az security iot-solution show", locals())


def create(display_name, iot_hubs, location, resource_group, solution_name):
    '''
    Create your IoT Security solution.
    '''
    return call_az("az security iot-solution create", locals())


def delete(resource_group, solution_name):
    '''
    Delete your IoT Security solution.
    '''
    return call_az("az security iot-solution delete", locals())


def update(resource_group, solution_name, display_name=None, iot_hubs=None):
    '''
    Update your IoT Security solution.
    '''
    return call_az("az security iot-solution update", locals())




from ...... pyaz_utils import call_az

def list(name, resource_group, workspace_name, filter=None, included_disabled=None, skip_token=None):
    '''
    List the recommended sensitivity classifications of a given SQL pool.
    '''
    return call_az("az synapse sql pool classification recommendation list", locals())


def enable(column, name, resource_group, schema, table, workspace_name):
    '''
    Enable sensitivity recommendations for a given column(recommendations are enabled by default on all columns).
    '''
    return call_az("az synapse sql pool classification recommendation enable", locals())


def disable(column, name, resource_group, schema, table, workspace_name):
    '''
    Disable sensitivity recommendations for a given column(recommendations are enabled by default on all columns).
    '''
    return call_az("az synapse sql pool classification recommendation disable", locals())




from ... pyaz_utils import call_az
from . import metadata, policy


def list(account_key=None, account_name=None, connection_string=None, include_metadata=None, include_snapshots=None, marker=None, num_results=None, prefix=None, sas_token=None, timeout=None):
    '''
    List the file shares in a storage account.
    '''
    return call_az("az storage share list", locals())


def create(name, account_key=None, account_name=None, connection_string=None, fail_on_exist=None, metadata=None, quota=None, sas_token=None, timeout=None):
    '''
    Creates a new share under the specified account.
    '''
    return call_az("az storage share create", locals())


def delete(name, account_key=None, account_name=None, connection_string=None, delete_snapshots=None, fail_not_exist=None, sas_token=None, snapshot=None, timeout=None):
    return call_az("az storage share delete", locals())


def generate_sas(name, account_key=None, account_name=None, cache_control=None, connection_string=None, content_disposition=None, content_encoding=None, content_language=None, content_type=None, expiry=None, https_only=None, ip=None, permissions=None, policy_name=None, start=None):
    return call_az("az storage share generate-sas", locals())


def stats(name, account_key=None, account_name=None, connection_string=None, sas_token=None, timeout=None):
    return call_az("az storage share stats", locals())


def show(name, account_key=None, account_name=None, connection_string=None, sas_token=None, snapshot=None, timeout=None):
    return call_az("az storage share show", locals())


def update(name, quota, account_key=None, account_name=None, connection_string=None, sas_token=None, timeout=None):
    return call_az("az storage share update", locals())


def snapshot(name, account_key=None, account_name=None, connection_string=None, metadata=None, quota=None, sas_token=None, timeout=None):
    return call_az("az storage share snapshot", locals())


def exists(name, account_key=None, account_name=None, connection_string=None, sas_token=None, snapshot=None, timeout=None):
    '''
    Check for the existence of a file share.
    '''
    return call_az("az storage share exists", locals())


def url(name, account_key=None, account_name=None, connection_string=None, protocol=None, sas_token=None, unc=None):
    '''
    Create a URI to access a file share.
    '''
    return call_az("az storage share url", locals())


def list_handle(name, account_key=None, account_name=None, connection_string=None, marker=None, max_results=None, path=None, recursive=None, sas_token=None, snapshot=None, timeout=None):
    '''
    List file handles of a file share.
    '''
    return call_az("az storage share list-handle", locals())


def close_handle(name, account_key=None, account_name=None, close_all=None, connection_string=None, handle_id=None, marker=None, path=None, recursive=None, sas_token=None, snapshot=None, timeout=None):
    '''
    Close file handles of a file share.
    '''
    return call_az("az storage share close-handle", locals())




from ... pyaz_utils import call_az

def list(expand=None, resource_group=None):
    '''
    Get all the Data Box Edge/Data Box Gateway devices in a resource group or in a subscription.
    '''
    return call_az("az databoxedge device list", locals())


def show(name, resource_group):
    '''
    Get the properties of the Data Box Edge/Data Box Gateway device.
    '''
    return call_az("az databoxedge device show", locals())


def create(name, resource_group, description=None, etag=None, friendly_name=None, location=None, model_description=None, no_wait=None, sku=None, status=None, tags=None):
    '''
    Create a Data Box Edge/Data Box Gateway resource.
    '''
    return call_az("az databoxedge device create", locals())


def update(name, resource_group, tags=None):
    '''
    Modify a Data Box Edge/Data Box Gateway resource.
    '''
    return call_az("az databoxedge device update", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Delete the Data Box Edge/Data Box Gateway device.
    '''
    return call_az("az databoxedge device delete", locals())


def download_update(name, resource_group, no_wait=None):
    '''
    Download the updates on a Data Box Edge/Data Box Gateway device.
    '''
    return call_az("az databoxedge device download-update", locals())


def install_update(name, resource_group, no_wait=None):
    '''
    Install the updates on the Data Box Edge/Data Box Gateway device.
    '''
    return call_az("az databoxedge device install-update", locals())


def scan_for_update(name, resource_group, no_wait=None):
    '''
    Scan for updates on a Data Box Edge/Data Box Gateway device.
    '''
    return call_az("az databoxedge device scan-for-update", locals())


def show_update_summary(name, resource_group):
    '''
    Get information about the availability of updates based on the last scan of the device. It also gets information about any ongoing download or install jobs on the device.
    '''
    return call_az("az databoxedge device show-update-summary", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the databoxedge device is met.
    '''
    return call_az("az databoxedge device wait", locals())




from ... pyaz_utils import call_az

def list(name, resource_group):
    '''
    List upstream settings of an existing SignalR Service.
    '''
    return call_az("az signalr upstream list", locals())


def update(name, resource_group, template):
    '''
    Update order sensitive upstream settings for an existing SignalR Service.
    '''
    return call_az("az signalr upstream update", locals())


def clear(name, resource_group):
    '''
    List upstream settings of an existing SignalR Service.
    '''
    return call_az("az signalr upstream clear", locals())




from .... pyaz_utils import call_az

def assign(name, registry, identities=None, resource_group=None):
    '''
    Update the managed identity for a task.
    '''
    return call_az("az acr task identity assign", locals())


def remove(name, registry, identities=None, resource_group=None):
    '''
    Remove managed identities for a task.
    '''
    return call_az("az acr task identity remove", locals())


def show(name, registry, resource_group=None):
    '''
    Display the managed identities for task.
    '''
    return call_az("az acr task identity show", locals())




from .... pyaz_utils import call_az

def upload(certificate_file, certificate_password, name, resource_group, slot=None):
    '''
    Upload an SSL certificate to a function app.
    '''
    return call_az("az functionapp config ssl upload", locals())


def list(resource_group):
    '''
    List SSL certificates for a function app.
    '''
    return call_az("az functionapp config ssl list", locals())


def show(certificate_name, resource_group):
    '''
    Show the details of an SSL certificate for a function app.
    '''
    return call_az("az functionapp config ssl show", locals())


def bind(certificate_thumbprint, name, resource_group, ssl_type, slot=None):
    '''
    Bind an SSL certificate to a function app.
    '''
    return call_az("az functionapp config ssl bind", locals())


def unbind(certificate_thumbprint, name, resource_group, slot=None):
    '''
    Unbind an SSL certificate from a function app.
    '''
    return call_az("az functionapp config ssl unbind", locals())


def delete(certificate_thumbprint, resource_group):
    '''
    Delete an SSL certificate from a function app.
    '''
    return call_az("az functionapp config ssl delete", locals())


def import_(key_vault, key_vault_certificate_name, name, resource_group):
    '''
    Import an SSL certificate to a function app from Key Vault.
    '''
    return call_az("az functionapp config ssl import", locals())


def create(hostname, name, resource_group, slot=None):
    '''
    Create a Managed Certificate for a hostname in a function app.
    '''
    return call_az("az functionapp config ssl create", locals())




from ... pyaz_utils import call_az
from . import firewall, network_rule, trusted_provider


def create(account, default_group=None, disable_encryption=None, encryption_type=None, key_name=None, key_vault_id=None, key_version=None, location=None, resource_group=None, tags=None, tier=None):
    '''
    Creates a Data Lake Store account.
    '''
    return call_az("az dls account create", locals())


def update(account, allow_azure_ips=None, default_group=None, firewall_state=None, key_version=None, resource_group=None, tags=None, tier=None, trusted_id_provider_state=None):
    '''
    Updates a Data Lake Store account.
    '''
    return call_az("az dls account update", locals())


def list(resource_group=None):
    '''
    Lists available Data Lake Store accounts.
    '''
    return call_az("az dls account list", locals())


def delete(account, resource_group=None):
    '''
    Delete a Data Lake Store account.
    '''
    return call_az("az dls account delete", locals())


def show(account, resource_group=None):
    '''
    Get the details of a Data Lake Store account.
    '''
    return call_az("az dls account show", locals())


def enable_key_vault(account, resource_group=None):
    '''
    Enable the use of Azure Key Vault for encryption of a Data Lake Store account.
    '''
    return call_az("az dls account enable-key-vault", locals())




from .... pyaz_utils import call_az

def set(user_name, password=None):
    '''
    Update deployment credentials.
    '''
    return call_az("az functionapp deployment user set", locals())


def show():
    return call_az("az functionapp deployment user show", locals())




from ... pyaz_utils import call_az
from . import namespace


def create(name, resource_group, capacity=None, location=None, tags=None):
    '''
    Create EventHubs Cluster
    '''
    return call_az("az eventhubs cluster create", locals())


def show(name, resource_group):
    '''
    Get the resource description of the specified Event Hubs Cluster.
    '''
    return call_az("az eventhubs cluster show", locals())


def list(resource_group):
    '''
    List the available Event Hubs Clusters within an ARM resource group.
    '''
    return call_az("az eventhubs cluster list", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the Cluster operation is completed.
    '''
    return call_az("az eventhubs cluster wait", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Delete an existing Event Hubs Cluster.
    '''
    return call_az("az eventhubs cluster delete", locals())


def available_region():
    '''
    List the quantity of available pre-provisioned Event Hubs Clusters, indexed by Azure region.
    '''
    return call_az("az eventhubs cluster available-region", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update tags of EventHubs Cluster
    '''
    return call_az("az eventhubs cluster update", locals())




from ... pyaz_utils import call_az

def create(name, parameters, resource_group):
    return call_az("az monitor autoscale-settings create", locals())


def delete(name, resource_group):
    return call_az("az monitor autoscale-settings delete", locals())


def show(name, resource_group):
    return call_az("az monitor autoscale-settings show", locals())


def list(resource_group):
    return call_az("az monitor autoscale-settings list", locals())


def get_parameters_template():
    return call_az("az monitor autoscale-settings get-parameters-template", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None):
    '''
    Updates an autoscale setting.
    '''
    return call_az("az monitor autoscale-settings update", locals())




from .... pyaz_utils import call_az
from . import delete_policy


def show(account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    return call_az("az storage blob service-properties show", locals())


def update(404_document=None, account_key=None, account_name=None, add=None, auth_mode=None, connection_string=None, delete_retention=None, delete_retention_period=None, force_string=None, index_document=None, remove=None, sas_token=None, set=None, static_website=None, timeout=None):
    '''
    Update storage blob service properties.
    '''
    return call_az("az storage blob service-properties update", locals())




from .... pyaz_utils import call_az

def update(cluster_name, durability_level, node_type, resource_group):
    '''
    Update the durability tier or VM SKU of a node type in the cluster.
    '''
    return call_az("az sf cluster durability update", locals())




from ... pyaz_utils import call_az
from . import certificate, consumer_group, devicestream, identity, message_enrichment, policy, route, routing_endpoint


def create(name, resource_group, c2d_max_delivery_count=None, c2d_ttl=None, disable_device_sas=None, disable_local_auth=None, disable_module_sas=None, feedback_lock_duration=None, feedback_max_delivery_count=None, feedback_ttl=None, fileupload_notification_lock_duration=None, fileupload_notification_max_delivery_count=None, fileupload_notification_ttl=None, fileupload_notifications=None, fileupload_sas_ttl=None, fileupload_storage_auth_type=None, fileupload_storage_connectionstring=None, fileupload_storage_container_name=None, fileupload_storage_container_uri=None, fileupload_storage_identity=None, location=None, mi_system_assigned=None, mi_user_assigned=None, min_tls_version=None, partition_count=None, retention_day=None, role=None, scopes=None, sku=None, tags=None, unit=None):
    '''
    Create an Azure IoT hub.
    '''
    return call_az("az iot hub create", locals())


def list(resource_group=None):
    '''
    List IoT hubs.
    '''
    return call_az("az iot hub list", locals())


def show_connection_string(all=None, hub_name=None, key=None, policy_name=None, resource_group=None):
    '''
    Show the connection strings for an IoT hub.
    '''
    return call_az("az iot hub show-connection-string", locals())


def show(name, resource_group=None):
    '''
    Get the details of an IoT hub.
    '''
    return call_az("az iot hub show", locals())


def update(name, add=None, c2d_max_delivery_count=None, c2d_ttl=None, disable_device_sas=None, disable_local_auth=None, disable_module_sas=None, feedback_lock_duration=None, feedback_max_delivery_count=None, feedback_ttl=None, fileupload_notification_lock_duration=None, fileupload_notification_max_delivery_count=None, fileupload_notification_ttl=None, fileupload_notifications=None, fileupload_sas_ttl=None, fileupload_storage_auth_type=None, fileupload_storage_connectionstring=None, fileupload_storage_container_name=None, fileupload_storage_container_uri=None, fileupload_storage_identity=None, force_string=None, remove=None, resource_group=None, retention_day=None, set=None, sku=None, tags=None, unit=None):
    '''
    Update metadata for an IoT hub.
    '''
    return call_az("az iot hub update", locals())


def delete(name, resource_group=None):
    '''
    Delete an IoT hub.
    '''
    return call_az("az iot hub delete", locals())


def list_skus(name, resource_group=None):
    '''
    List available pricing tiers.
    '''
    return call_az("az iot hub list-skus", locals())


def show_quota_metrics(name, resource_group=None):
    '''
    Get the quota metrics for an IoT hub.
    '''
    return call_az("az iot hub show-quota-metrics", locals())


def show_stats(name, resource_group=None):
    '''
    Get the statistics for an IoT hub.
    '''
    return call_az("az iot hub show-stats", locals())


def manual_failover(name, no_wait=None, resource_group=None):
    '''
    Initiate a manual failover for the IoT Hub to the geo-paired disaster recovery region.
    '''
    return call_az("az iot hub manual-failover", locals())




from .... pyaz_utils import call_az

def list(product_id, resource_group, service_name):
    '''
    Lists a collection of the APIs associated with a product.
    '''
    return call_az("az apim product api list", locals())


def check(api_id, product_id, resource_group, service_name):
    '''
    Checks that API entity specified by identifier is associated with the Product entity.
    '''
    return call_az("az apim product api check", locals())


def add(api_id, product_id, resource_group, service_name):
    '''
    Add an API to the specified product.
    '''
    return call_az("az apim product api add", locals())


def delete(api_id, product_id, resource_group, service_name):
    '''
    Deletes the specified API from the specified product.
    '''
    return call_az("az apim product api delete", locals())




from .... pyaz_utils import call_az
from . import condition, dimension


def create(condition, name, resource_group, scopes, action=None, auto_mitigate=None, description=None, disabled=None, evaluation_frequency=None, severity=None, tags=None, target_resource_region=None, target_resource_type=None, window_size=None):
    '''
    Create a metric-based alert rule.
    '''
    return call_az("az monitor metrics alert create", locals())


def delete(name, resource_group):
    '''
    Delete a metrics-based alert rule.
    '''
    return call_az("az monitor metrics alert delete", locals())


def list(resource_group=None):
    '''
    List metric-based alert rules.
    '''
    return call_az("az monitor metrics alert list", locals())


def show(name, resource_group):
    '''
    Show a metrics-based alert rule.
    '''
    return call_az("az monitor metrics alert show", locals())


def update(name, resource_group, add=None, add_action=None, add_condition=None, auto_mitigate=None, description=None, enabled=None, evaluation_frequency=None, force_string=None, remove=None, remove_actions=None, remove_conditions=None, scopes=None, set=None, severity=None, tags=None, window_size=None):
    '''
    Update a metric-based alert rule.
    '''
    return call_az("az monitor metrics alert update", locals())




from .. pyaz_utils import call_az

def create(key_url, name, resource_group, source_vault, enable_auto_key_rotation=None, encryption_type=None, location=None, no_wait=None, tags=None):
    '''
    Create a disk encryption set.
    '''
    return call_az("az disk-encryption-set create", locals())


def delete(name, resource_group):
    '''
    Delete a disk encryption set.
    '''
    return call_az("az disk-encryption-set delete", locals())


def update(name, resource_group, add=None, enable_auto_key_rotation=None, force_string=None, key_url=None, remove=None, set=None, source_vault=None):
    '''
    Update a disk encryption set.
    '''
    return call_az("az disk-encryption-set update", locals())


def show(name, resource_group):
    '''
    Get information of a disk encryption sets.
    '''
    return call_az("az disk-encryption-set show", locals())


def list(resource_group=None):
    '''
    List disk encryption sets.
    '''
    return call_az("az disk-encryption-set list", locals())


def list_associated_resources(name, resource_group):
    return call_az("az disk-encryption-set list-associated-resources", locals())




from ... pyaz_utils import call_az
from . import backup_properties, encryption, identity


def create(location, name, resource_group, tags=None):
    '''
    Create a new Recovery Services vault.
    '''
    return call_az("az backup vault create", locals())


def show(name, resource_group):
    '''
    Show details of a particular Recovery service vault.
    '''
    return call_az("az backup vault show", locals())


def list(resource_group=None):
    '''
    List Recovery service vaults within a subscription.
    '''
    return call_az("az backup vault list", locals())


def delete(name, resource_group, force=None, yes=None):
    '''
    Delete an existing Recovery services vault.
    '''
    return call_az("az backup vault delete", locals())




from ... pyaz_utils import call_az
from . import access_restriction, appsettings, container, hostname, ssl


def set(name, resource_group, always_on=None, auto_heal_enabled=None, ftps_state=None, generic_configurations=None, http20_enabled=None, java_container=None, java_container_version=None, java_version=None, linux_fx_version=None, min_tls_version=None, net_framework_version=None, number_of_workers=None, php_version=None, prewarmed_instance_count=None, python_version=None, remote_debugging_enabled=None, slot=None, startup_file=None, use_32bit_worker_process=None, vnet_route_all_enabled=None, web_sockets_enabled=None):
    '''
    Set an existing function app's configuration.
    '''
    return call_az("az functionapp config set", locals())


def show(name, resource_group, slot=None):
    '''
    Get the details of an existing function app's configuration.
    '''
    return call_az("az functionapp config show", locals())




from .... pyaz_utils import call_az

def add(filter_name, auth_mode=None, connection_string=None, endpoint=None, feature=None, filter_parameters=None, index=None, key=None, label=None, name=None, yes=None):
    '''
    Add a filter to a feature flag.
    '''
    return call_az("az appconfig feature filter add", locals())


def delete(all=None, auth_mode=None, connection_string=None, endpoint=None, feature=None, filter_name=None, index=None, key=None, label=None, name=None, yes=None):
    '''
    Delete a filter from a feature flag.
    '''
    return call_az("az appconfig feature filter delete", locals())


def show(filter_name, auth_mode=None, connection_string=None, endpoint=None, feature=None, index=None, key=None, label=None, name=None):
    '''
    Show filters of a feature flag.
    '''
    return call_az("az appconfig feature filter show", locals())


def list(all=None, auth_mode=None, connection_string=None, endpoint=None, feature=None, key=None, label=None, name=None, top=None):
    '''
    List all filters for a feature flag.
    '''
    return call_az("az appconfig feature filter list", locals())




from ... pyaz_utils import call_az

def show(name, resource_group):
    '''
    Show the details of an action group
    '''
    return call_az("az monitor action-group show", locals())


def create(name, resource_group, action=None, short_name=None, tags=None):
    '''
    Create a new action group
    '''
    return call_az("az monitor action-group create", locals())


def delete(name, resource_group):
    return call_az("az monitor action-group delete", locals())


def enable_receiver(action_group, name, resource_group):
    '''
    Enable a receiver in an action group.
    '''
    return call_az("az monitor action-group enable-receiver", locals())


def list(resource_group=None):
    '''
    List action groups under a resource group or the current subscription
    '''
    return call_az("az monitor action-group list", locals())


def update(name, resource_group, add=None, add_action=None, force_string=None, remove=None, remove_action=None, set=None, short_name=None, tags=None):
    '''
    Update an action group
    '''
    return call_az("az monitor action-group update", locals())




from ... pyaz_utils import call_az

def get_default_for_vm(resource_group, vault_name):
    '''
    Get the default policy with default values to backup a VM.
    '''
    return call_az("az backup policy get-default-for-vm", locals())


def show(name, resource_group, vault_name):
    '''
    Show details of a particular policy.
    '''
    return call_az("az backup policy show", locals())


def list(resource_group, vault_name, backup_management_type=None, workload_type=None):
    '''
    List all policies for a Recovery services vault.
    '''
    return call_az("az backup policy list", locals())


def list_associated_items(name, resource_group, vault_name, backup_management_type=None):
    '''
    List all items protected by a backup policy.
    '''
    return call_az("az backup policy list-associated-items", locals())


def set(resource_group, vault_name, backup_management_type=None, fix_for_inconsistent_items=None, name=None, policy=None):
    '''
    Update the existing policy with the provided details.
    '''
    return call_az("az backup policy set", locals())


def delete(name, resource_group, vault_name):
    '''
    Delete a backup policy which doesn't have any associated backup items.
    '''
    return call_az("az backup policy delete", locals())


def create(backup_management_type, name, policy, resource_group, vault_name, workload_type=None):
    '''
    Create a new policy for the given BackupManagementType and workloadType.
    '''
    return call_az("az backup policy create", locals())




from .... pyaz_utils import call_az

def create(name, resource_group, authorization_message=None, cidr=None, cip_prefix_parent=None, location=None, no_wait=None, signed_message=None, tags=None, zone=None):
    '''
    Create a custom IP prefix resource.
    '''
    return call_az("az network custom-ip prefix create", locals())


def delete(name, resource_group):
    '''
    Delete a custom IP prefix resource.
    '''
    return call_az("az network custom-ip prefix delete", locals())


def list(resource_group=None):
    '''
    List custom IP prefix resources.
    '''
    return call_az("az network custom-ip prefix list", locals())


def show(name, resource_group, expand=None):
    '''
    Get the details of a custom IP prefix resource.
    '''
    return call_az("az network custom-ip prefix show", locals())


def update(name, resource_group, add=None, authorization_message=None, force_string=None, no_wait=None, remove=None, set=None, signed_message=None, state=None, tags=None):
    '''
    Update a custom IP prefix resource.
    '''
    return call_az("az network custom-ip prefix update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, expand=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the custom ip prefix is met.
    '''
    return call_az("az network custom-ip prefix wait", locals())




from .... pyaz_utils import call_az

def list(resource_group, workspace_name):
    '''
    List all firewall rules.
    '''
    return call_az("az synapse workspace firewall-rule list", locals())


def show(name, resource_group, workspace_name):
    '''
    Get a firewall rule.
    '''
    return call_az("az synapse workspace firewall-rule show", locals())


def create(end_ip_address, name, resource_group, start_ip_address, workspace_name, no_wait=None):
    '''
    Create a firewall rule.
    '''
    return call_az("az synapse workspace firewall-rule create", locals())


def update(name, resource_group, workspace_name, end_ip_address=None, no_wait=None, start_ip_address=None):
    '''
    Update a firewall rule.
    '''
    return call_az("az synapse workspace firewall-rule update", locals())


def delete(name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Delete a firewall rule.
    '''
    return call_az("az synapse workspace firewall-rule delete", locals())


def wait(resource_group, rule_name, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a firewall rule is met.
    '''
    return call_az("az synapse workspace firewall-rule wait", locals())




from .... pyaz_utils import call_az

def list(gateway_name, resource_group):
    '''
    List HTTP listeners.
    '''
    return call_az("az network application-gateway http-listener list", locals())


def show(gateway_name, name, resource_group):
    '''
    Get the details of an HTTP listener.
    '''
    return call_az("az network application-gateway http-listener show", locals())


def delete(gateway_name, name, resource_group, no_wait=None):
    '''
    Delete an HTTP listener.
    '''
    return call_az("az network application-gateway http-listener delete", locals())


def create(frontend_port, gateway_name, name, resource_group, frontend_ip=None, host_name=None, host_names=None, no_wait=None, ssl_cert=None, ssl_profile_id=None, waf_policy=None):
    '''
    Create an HTTP listener.
    '''
    return call_az("az network application-gateway http-listener create", locals())


def update(gateway_name, name, resource_group, add=None, force_string=None, frontend_ip=None, frontend_port=None, host_name=None, host_names=None, no_wait=None, remove=None, set=None, ssl_cert=None, ssl_profile_id=None, waf_policy=None):
    '''
    Update an HTTP listener.
    '''
    return call_az("az network application-gateway http-listener update", locals())




from ... pyaz_utils import call_az

def create(location, resource_group, service_name, service_topology_name, target_location, target_subscription_id, tags=None):
    '''
    Creates a service under the specified service topology.
    '''
    return call_az("az deploymentmanager service create", locals())


def delete(resource_group, service_name, service_topology_name):
    '''
    Deletes the service topology.
    '''
    return call_az("az deploymentmanager service delete", locals())


def show(resource_group, service_name, service_topology_name):
    '''
    Get the details of a service.
    '''
    return call_az("az deploymentmanager service show", locals())


def list(resource_group, service_topology_name):
    '''
    List all services in a service topology.
    '''
    return call_az("az deploymentmanager service list", locals())


def update(resource_group, service_name, service_topology_name, add=None, force_string=None, remove=None, set=None, tags=None, target_location=None, target_subscription_id=None):
    '''
    Updates the service.
    '''
    return call_az("az deploymentmanager service update", locals())




from ... pyaz_utils import call_az
from . import prefix


def delete(name, resource_group):
    '''
    Delete a public IP address.
    '''
    return call_az("az network public-ip delete", locals())


def show(name, resource_group, expand=None):
    '''
    Get the details of a public IP address.
    '''
    return call_az("az network public-ip show", locals())


def list(resource_group=None):
    '''
    List public IP addresses.
    '''
    return call_az("az network public-ip list", locals())


def create(name, resource_group, allocation_method=None, dns_name=None, edge_zone=None, idle_timeout=None, ip_address=None, ip_tags=None, location=None, public_ip_prefix=None, reverse_fqdn=None, sku=None, tags=None, tier=None, version=None, zone=None):
    '''
    Create a public IP address.
    '''
    return call_az("az network public-ip create", locals())


def update(name, resource_group, add=None, allocation_method=None, dns_name=None, force_string=None, idle_timeout=None, ip_tags=None, public_ip_prefix=None, remove=None, reverse_fqdn=None, set=None, sku=None, tags=None, version=None):
    '''
    Update a public IP address.
    '''
    return call_az("az network public-ip update", locals())




from ... pyaz_utils import call_az
from . import correlation_scheme, load_metrics


def list(application, cluster_name, resource_group):
    '''
    List managed services of a given managed application.
    '''
    return call_az("az sf managed-service list", locals())


def delete(application, cluster_name, name, resource_group):
    '''
    Delete a managed service.
    '''
    return call_az("az sf managed-service delete", locals())


def show(application, cluster_name, name, resource_group):
    '''
    Get a service.
    '''
    return call_az("az sf managed-service show", locals())


def create(application, cluster_name, name, resource_group, state, type, default_move_cost=None, has_persisted_state=None, high_key=None, instance_count=None, low_key=None, min_instance_count=None, min_instance_percentage=None, min_replica_set_size=None, partition_count=None, partition_names=None, partition_scheme=None, placement_constraints=None, quorum_loss_wait_duration=None, replica_restart_wait_duration=None, service_package_activation_mode=None, service_placement_time_limit=None, stand_by_replica_keep_duration=None, tags=None, target_replica_set_size=None):
    '''
    Create a new managed service on an Azure Service Fabric managed cluster.
    '''
    return call_az("az sf managed-service create", locals())


def update(application, cluster_name, name, resource_group, default_move_cost=None, instance_count=None, min_instance_count=None, min_instance_percentage=None, min_replica_set_size=None, placement_constraints=None, quorum_loss_wait_duration=None, replica_restart_wait_duration=None, service_placement_time_limit=None, stand_by_replica_keep_duration=None, tags=None, target_replica_set_size=None):
    '''
    Update a managed service.
    '''
    return call_az("az sf managed-service update", locals())




from .... pyaz_utils import call_az

def postgres(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None):
    '''
    Update a webapp to postgres connection.
    '''
    return call_az("az webapp connection update postgres", locals())


def postgres_flexible(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None):
    '''
    Update a webapp to postgres-flexible connection.
    '''
    return call_az("az webapp connection update postgres-flexible", locals())


def mysql(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None):
    '''
    Update a webapp to mysql connection.
    '''
    return call_az("az webapp connection update mysql", locals())


def mysql_flexible(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None):
    '''
    Update a webapp to mysql-flexible connection.
    '''
    return call_az("az webapp connection update mysql-flexible", locals())


def cosmos_cassandra(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, system_identity=None, user_identity=None):
    '''
    Update a webapp to cosmos-cassandra connection.
    '''
    return call_az("az webapp connection update cosmos-cassandra", locals())


def cosmos_gremlin(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, system_identity=None, user_identity=None):
    '''
    Update a webapp to cosmos-gremlin connection.
    '''
    return call_az("az webapp connection update cosmos-gremlin", locals())


def cosmos_mongo(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, system_identity=None, user_identity=None):
    '''
    Update a webapp to cosmos-mongo connection.
    '''
    return call_az("az webapp connection update cosmos-mongo", locals())


def cosmos_table(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, system_identity=None, user_identity=None):
    '''
    Update a webapp to cosmos-table connection.
    '''
    return call_az("az webapp connection update cosmos-table", locals())


def cosmos_sql(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, system_identity=None, user_identity=None):
    '''
    Update a webapp to cosmos-sql connection.
    '''
    return call_az("az webapp connection update cosmos-sql", locals())


def storage_blob(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, system_identity=None, user_identity=None):
    '''
    Update a webapp to storage-blob connection.
    '''
    return call_az("az webapp connection update storage-blob", locals())


def storage_queue(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, system_identity=None, user_identity=None):
    '''
    Update a webapp to storage-queue connection.
    '''
    return call_az("az webapp connection update storage-queue", locals())


def storage_file(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None):
    '''
    Update a webapp to storage-file connection.
    '''
    return call_az("az webapp connection update storage-file", locals())


def storage_table(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None):
    '''
    Update a webapp to storage-table connection.
    '''
    return call_az("az webapp connection update storage-table", locals())


def keyvault(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, service_principal=None, system_identity=None, user_identity=None):
    '''
    Update a webapp to keyvault connection.
    '''
    return call_az("az webapp connection update keyvault", locals())


def signalr(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, system_identity=None, user_identity=None):
    '''
    Update a webapp to signalr connection.
    '''
    return call_az("az webapp connection update signalr", locals())


def confluent_cloud(connection, bootstrap_server=None, client_type=None, kafka_key=None, kafka_secret=None, name=None, no_wait=None, resource_group=None, schema_key=None, schema_registry=None, schema_secret=None, source_id=None):
    '''
    Update a webapp to confluent-cloud connection.
    '''
    return call_az("az webapp connection update confluent-cloud", locals())




from .... pyaz_utils import call_az

def list(account_endpoint=None, account_key=None, account_name=None, filter=None):
    '''
    Lists all Virtual Machine Images supported by the Azure Batch service.
    '''
    return call_az("az batch pool supported-images list", locals())




from ... pyaz_utils import call_az
from . import ipsec_policy, packet_capture, shared_key


def create(name, resource_group, vnet_gateway1, authorization_key=None, egress_nat_rule=None, enable_bgp=None, express_route_circuit2=None, express_route_gateway_bypass=None, ingress_nat_rule=None, local_gateway2=None, location=None, routing_weight=None, shared_key=None, tags=None, use_policy_based_traffic_selectors=None, validate=None, vnet_gateway2=None):
    '''
    Create a VPN connection.
    '''
    return call_az("az network vpn-connection create", locals())


def delete(name, resource_group):
    '''
    Delete a VPN connection.
    '''
    return call_az("az network vpn-connection delete", locals())


def show(name, resource_group):
    '''
    Get the details of a VPN connection.
    '''
    return call_az("az network vpn-connection show", locals())


def list(resource_group, vnet_gateway=None):
    '''
    List all VPN connections.
    '''
    return call_az("az network vpn-connection list", locals())


def update(name, resource_group, add=None, enable_bgp=None, express_route_gateway_bypass=None, force_string=None, remove=None, routing_weight=None, set=None, shared_key=None, tags=None, use_policy_based_traffic_selectors=None):
    '''
    Update a VPN connection.
    '''
    return call_az("az network vpn-connection update", locals())


def list_ike_sas(name, resource_group):
    '''
    List IKE Security Associations for a VPN connection.
    '''
    return call_az("az network vpn-connection list-ike-sas", locals())


def show_device_config_script(device_family, firmware_version, name, resource_group, vendor):
    '''
    Get a XML format representation for VPN connection device configuration script.
    '''
    return call_az("az network vpn-connection show-device-config-script", locals())

